# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MEAN_METADATA = Metadata(
    id="d608ce9fea57e85bfbfc19ea1af870315c233573.boutiques",
    name="mean",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class MeanOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mean(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_log: OutputPathType
    """Output log of mean computation"""


def mean(
    datafile: InputPathType,
    maskfile: InputPathType,
    verbose_flag: bool = False,
    debug_level: float | None = None,
    timing_flag: bool = False,
    log_dir: str | None = None,
    forcedir_flag: bool = False,
    inference_tech: str | None = None,
    num_jumps: float | None = None,
    num_burnin: float | None = None,
    num_sample_every: float | None = None,
    num_update_proposalevery: float | None = None,
    acceptance_rate: float | None = None,
    seed: float | None = None,
    error_precision: float | None = None,
    noamp_flag: bool = False,
    prior_mean: float | None = None,
    prior_std: float | None = None,
    runner: Runner | None = None,
) -> MeanOutputs:
    """
    Diagnostic tool for analyzing and computing mean values for FSL data.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        datafile: Regressor data file.
        maskfile: Mask file.
        verbose_flag: Switch on diagnostic messages.
        debug_level: Set debug level.
        timing_flag: Turn timing on.
        log_dir: Log directory (default is logdir).
        forcedir_flag: Use the actual directory name given - i.e. don't add +\
            to make a new directory.
        inference_tech: Inference technique: mcmc or laplace (default is mcmc).
        num_jumps: Number of jumps to be made by MCMC (default is 5000).
        num_burnin: Number of jumps at start of MCMC to be discarded (default\
            is 500).
        num_sample_every: Number of jumps for each sample (MCMC) (default is 1).
        num_update_proposalevery: Number of jumps for each update to the\
            proposal density std (MCMC) (default is 40).
        acceptance_rate: Acceptance rate to aim for (MCMC) (default is 0.6).
        seed: Seed for pseudo random number generator.
        error_precision: Value to fix error precision to (default is -1, which\
            means error precision is not fixed).
        noamp_flag: Turn off Analytical Marginalisation of error Precision.
        prior_mean: Prior mean.
        prior_std: Prior standard deviation.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MeanOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MEAN_METADATA)
    cargs = []
    cargs.append("mean")
    cargs.extend([
        "--data",
        execution.input_file(datafile)
    ])
    cargs.extend([
        "--mask",
        execution.input_file(maskfile)
    ])
    if verbose_flag:
        cargs.append("--verbose")
    if debug_level is not None:
        cargs.extend([
            "--debug",
            str(debug_level)
        ])
    if timing_flag:
        cargs.append("--to")
    if log_dir is not None:
        cargs.extend([
            "--ld",
            log_dir
        ])
    if forcedir_flag:
        cargs.append("--forcedir")
    if inference_tech is not None:
        cargs.extend([
            "--inf",
            inference_tech
        ])
    if num_jumps is not None:
        cargs.extend([
            "--nj",
            str(num_jumps)
        ])
    if num_burnin is not None:
        cargs.extend([
            "--bi",
            str(num_burnin)
        ])
    if num_sample_every is not None:
        cargs.extend([
            "--se",
            str(num_sample_every)
        ])
    if num_update_proposalevery is not None:
        cargs.extend([
            "--upe",
            str(num_update_proposalevery)
        ])
    if acceptance_rate is not None:
        cargs.extend([
            "--arate",
            str(acceptance_rate)
        ])
    if seed is not None:
        cargs.extend([
            "--seed",
            str(seed)
        ])
    if error_precision is not None:
        cargs.extend([
            "--prec",
            str(error_precision)
        ])
    if noamp_flag:
        cargs.append("--noamp")
    if prior_mean is not None:
        cargs.extend([
            "--pm",
            str(prior_mean)
        ])
    if prior_std is not None:
        cargs.extend([
            "--ps",
            str(prior_std)
        ])
    ret = MeanOutputs(
        root=execution.output_file("."),
        output_log=execution.output_file("logdir/mean_output.txt"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MEAN_METADATA",
    "MeanOutputs",
    "mean",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DENOISE_IMAGE_METADATA = Metadata(
    id="510d45985961f8069b7889eeca0f9b9d13f57a86.boutiques",
    name="DenoiseImage",
    package="ants",
    container_image_tag="antsx/ants:v2.5.3",
)


class DenoiseImageOutputs(typing.NamedTuple):
    """
    Output object returned when calling `denoise_image(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    corrected_image: OutputPathType
    """The noise corrected version of the input image."""
    noise_image: OutputPathType
    """Estimated noise image."""


def denoise_image(
    input_image: InputPathType,
    corrected_image_path: str,
    noise_image_path: str,
    image_dimensionality: typing.Literal[2, 3, 4] | None = None,
    noise_model: typing.Literal["Gaussian", "Rician"] | None = None,
    shrink_factor: int | None = None,
    mask_image: InputPathType | None = None,
    patch_radius: str | None = None,
    search_radius: str | None = None,
    verbose: typing.Literal[0, 1] | None = None,
    runner: Runner | None = None,
) -> DenoiseImageOutputs:
    """
    Denoise an image using a spatially adaptive filter originally described in J. V.
    Manjon, P. Coupe, Luis Marti-Bonmati, D. L. Collins, and M. Robles. Adaptive
    Non-Local Means Denoising of MR Images With Spatially Varying Noise Levels,
    Journal of Magnetic Resonance Imaging, 31:192-203, June 2010.
    
    Author: ANTs Developers
    
    URL: https://github.com/ANTsX/ANTs
    
    Args:
        input_image: -i, --input-image inputImageFilename. A scalar image is\
            expected as input for noise correction.
        corrected_image_path: The noise corrected version of the input image.
        noise_image_path: Estimated noise image.
        image_dimensionality: -d, --image-dimensionality 2/3/4. This option\
            forces the image to be treated as a specified-dimensional image. If not\
            specified, the program tries to infer the dimensionality from the input\
            image.
        noise_model: -n, --noise-model Rician/(Gaussian). Employ a Rician or\
            Gaussian noise model.
        shrink_factor: -s, --shrink-factor (1)/2/3/... Running noise correction\
            on large images can be time consuming. To lessen computation time, the\
            input image can be resampled. The shrink factor, specified as a single\
            integer, describes this resampling. Shrink factor = 1 is the default.
        mask_image: -x, --mask-image maskImageFilename. If a mask image is\
            specified, denoising is only performed in the mask region.
        patch_radius: -p, --patch-radius 1x1x1. Patch radius. Default is 1x1x1.
        search_radius: -r, --search-radius 2x2x2. Search radius. Default is\
            2x2x2.
        verbose: Verbose output.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DenoiseImageOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DENOISE_IMAGE_METADATA)
    cargs = []
    cargs.append("DenoiseImage")
    if image_dimensionality is not None:
        cargs.extend([
            "--image-dimensionality",
            str(image_dimensionality)
        ])
    if noise_model is not None:
        cargs.extend([
            "--noise-model",
            noise_model
        ])
    if shrink_factor is not None:
        cargs.extend([
            "--shrink-factor",
            str(shrink_factor)
        ])
    if mask_image is not None:
        cargs.extend([
            "--mask-image",
            execution.input_file(mask_image)
        ])
    if patch_radius is not None:
        cargs.extend([
            "--patch-radius",
            patch_radius
        ])
    if search_radius is not None:
        cargs.extend([
            "--search-radius",
            search_radius
        ])
    if verbose is not None:
        cargs.extend([
            "--verbose",
            str(verbose)
        ])
    cargs.extend([
        "--input-image",
        execution.input_file(input_image)
    ])
    cargs.append("--output")
    cargs.append("[" + corrected_image_path + "," + noise_image_path + "]")
    ret = DenoiseImageOutputs(
        root=execution.output_file("."),
        corrected_image=execution.output_file(corrected_image_path),
        noise_image=execution.output_file(noise_image_path),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DENOISE_IMAGE_METADATA",
    "DenoiseImageOutputs",
    "denoise_image",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V_3D_THREETO_RGB_METADATA = Metadata(
    id="0e50efb1e4d4adac2b47669f62f58516c895a1cf.boutiques",
    name="3dThreetoRGB",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class V3dThreetoRgbOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v_3d_threeto_rgb(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dataset_head: OutputPathType | None
    """RGB-valued dataset output"""
    output_dataset_brik: OutputPathType | None
    """RGB-valued dataset output"""


def v_3d_threeto_rgb(
    input_dataset: InputPathType,
    output_prefix: str | None = None,
    scale_factor: float | None = None,
    mask_dataset: InputPathType | None = None,
    fim: bool = False,
    anat: bool = False,
    input_dataset2: InputPathType | None = None,
    input_dataset3: InputPathType | None = None,
    runner: Runner | None = None,
) -> V3dThreetoRgbOutputs:
    """
    Converts 3 sub-bricks of input to an RGB-valued dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        input_dataset: Input dataset or first dataset if three datasets are\
            provided.
        output_prefix: Write output into dataset with specified prefix.
        scale_factor: Multiply input values by this factor before using as RGB.
        mask_dataset: Only output nonzero values where the mask dataset is\
            nonzero.
        fim: Write result as a 'fim' type dataset (default behavior).
        anat: Write result as a anatomical type dataset.
        input_dataset2: Second dataset, required only if three datasets are\
            provided.
        input_dataset3: Third dataset, required only if three datasets are\
            provided.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `V3dThreetoRgbOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V_3D_THREETO_RGB_METADATA)
    cargs = []
    cargs.append("3dThreetoRGB")
    if output_prefix is not None:
        cargs.extend([
            "-prefix",
            output_prefix
        ])
    if scale_factor is not None:
        cargs.extend([
            "-scale",
            str(scale_factor)
        ])
    if mask_dataset is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask_dataset)
        ])
    if fim:
        cargs.append("-fim")
    if anat:
        cargs.append("-anat")
    cargs.append(execution.input_file(input_dataset))
    cargs.append("[DATASET1]")
    if input_dataset2 is not None:
        cargs.append(execution.input_file(input_dataset2))
    if input_dataset3 is not None:
        cargs.append(execution.input_file(input_dataset3))
    ret = V3dThreetoRgbOutputs(
        root=execution.output_file("."),
        output_dataset_head=execution.output_file(output_prefix + "+rgb.HEAD") if (output_prefix is not None) else None,
        output_dataset_brik=execution.output_file(output_prefix + "+rgb.BRIK") if (output_prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "V3dThreetoRgbOutputs",
    "V_3D_THREETO_RGB_METADATA",
    "v_3d_threeto_rgb",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

UBER_ALIGN_TEST_PY_METADATA = Metadata(
    id="1cdb35a694ecfd6f154d70ecf75d0b5138262e0f.boutiques",
    name="uber_align_test.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class UberAlignTestPyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `uber_align_test_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def uber_align_test_py(
    no_gui: bool = False,
    print_script: bool = False,
    save_script: str | None = None,
    user_variable: list[str] | None = None,
    qt_opts: str | None = None,
    help_: bool = False,
    help_gui: bool = False,
    history: bool = False,
    show_valid_opts: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> UberAlignTestPyOutputs:
    """
    Generate script to test anatomical/EPI alignment.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        no_gui: Run without the graphical user interface (GUI).
        print_script: Print the generated script to standard output.
        save_script: Save the generated script to the specified file.
        user_variable: Specify user variables for alignment.
        qt_opts: Pass PyQt4 options directly to the GUI.
        help_: Show help information.
        help_gui: Show help information for the GUI.
        history: Show command history.
        show_valid_opts: Show valid options.
        version: Show version information.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `UberAlignTestPyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(UBER_ALIGN_TEST_PY_METADATA)
    cargs = []
    cargs.append("uber_align_test.py")
    if no_gui:
        cargs.append("-no_gui")
    if print_script:
        cargs.append("-print_script")
    if save_script is not None:
        cargs.extend([
            "-save_script",
            save_script
        ])
    if user_variable is not None:
        cargs.extend([
            "-uvar",
            *user_variable
        ])
    if qt_opts is not None:
        cargs.extend([
            "-qt_opts",
            qt_opts
        ])
    if help_:
        cargs.append("-help")
    if help_gui:
        cargs.append("-help_gui")
    if history:
        cargs.append("-hist")
    if show_valid_opts:
        cargs.append("-show_valid_opts")
    if version:
        cargs.append("-ver")
    ret = UberAlignTestPyOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "UBER_ALIGN_TEST_PY_METADATA",
    "UberAlignTestPyOutputs",
    "uber_align_test_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_VOL2VOL_METADATA = Metadata(
    id="77d3504583fc4d7f61c4962c2cc361faf9664a7d.boutiques",
    name="mri_vol2vol",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriVol2volOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_vol2vol(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_volume: OutputPathType
    """Resampled output volume."""


def mri_vol2vol(
    movvol: InputPathType,
    targvol: InputPathType,
    outvol: InputPathType,
    dispvol: InputPathType | None = None,
    downsample: list[float] | None = None,
    register_dat: InputPathType | None = None,
    lta: InputPathType | None = None,
    lta_inv: InputPathType | None = None,
    fsl: InputPathType | None = None,
    xfm: InputPathType | None = None,
    inv: bool = False,
    tal: bool = False,
    talres: float | None = None,
    talxfm: InputPathType | None = None,
    m3z: InputPathType | None = None,
    inv_morph: bool = False,
    fstarg: str | None = None,
    crop: float | None = None,
    slice_crop: list[float] | None = None,
    slice_reverse: bool = False,
    slice_bias: float | None = None,
    interp: str | None = None,
    fill_average: bool = False,
    fill_conserve: bool = False,
    fill_up: float | None = None,
    mul: float | None = None,
    precision: str | None = None,
    keep_precision: bool = False,
    kernel: bool = False,
    copy_ctab: bool = False,
    gcam: str | None = None,
    spm_warp: str | None = None,
    map_point: str | None = None,
    map_point_inv_lta: str | None = None,
    no_resample: bool = False,
    rot: list[float] | None = None,
    trans: list[float] | None = None,
    shear: list[float] | None = None,
    reg_final: InputPathType | None = None,
    synth: bool = False,
    seed: float | None = None,
    save_reg: bool = False,
    debug: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> MriVol2volOutputs:
    """
    Resamples a volume into another field-of-view using various types of matrices
    (FreeSurfer, FSL, SPM, and MNI).
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        movvol: Input volume (or output template with --inv).
        targvol: Output template (or input with --inv).
        outvol: Output volume.
        dispvol: Displacement volume.
        downsample: Downsample factor (e.g., 2) (do not include a targ or\
            registration).
        register_dat: tkRAS-to-tkRAS matrix (tkregister2 format).
        lta: Linear Transform Array (usually only 1 transform).
        lta_inv: LTA, invert (may not be the same as --lta --inv with --fstal).
        fsl: fslRAS-to-fslRAS matrix (FSL format).
        xfm: ScannerRAS-to-ScannerRAS matrix (MNI format).
        inv: Sample from targ to mov.
        tal: Map to a sub FOV of MNI305 (with --reg only).
        talres: Set voxel size 1mm or 2mm (default is 1).
        talxfm: Path to the talairach transformation file. Default is\
            talairach.xfm (looks in mri/transforms).
        m3z: Non-linear morph encoded in the m3z format.
        inv_morph: Compute and use the inverse of the m3z morph.
        fstarg: Optionally use the specified volume from the subject in --reg\
            as target. Default is orig.mgz.
        crop: Crop and change voxel size.
        slice_crop: Crop output slices to be within specified start and end\
            indices.
        slice_reverse: Reverse order of slices, update vox2ras.
        slice_bias: Apply half-cosine bias field.
        interp: Interpolation method: cubic, trilin, or nearest (default is\
            trilin).
        fill_average: Compute mean of all source voxels in a given target voxel.
        fill_conserve: Compute sum of all source voxels in a given target voxel.
        fill_up: Source upsampling factor for --fill-{avg,cons} (default is 2).
        mul: Multiply output by the specified value.
        precision: Output precision (default is float).
        keep_precision: Set output precision to that of the input.
        kernel: Save the trilinear interpolation kernel at each voxel instead\
            of the interpolated image.
        copy_ctab: Setenv FS_COPY_HEADER_CTAB to copy any ctab in the mov\
            header.
        gcam: GCAM warp procedure.
        spm_warp: SPM warp procedure.
        map_point: Standalone option to map a point to another space.
        map_point_inv_lta: Same as --map-point but inverts the LTA.
        no_resample: Do not resample, just change vox2ras matrix.
        rot: Rotation angles (degrees) to apply to registration matrix.
        trans: Translation (mm) to apply to registration matrix.
        shear: Shearing factors. Sxy Sxz Syz with xz as in-plane.
        reg_final: Final registration matrix after rotation and translation\
            (but not inversion).
        synth: Replace input with white Gaussian noise.
        seed: Seed for synth (default is to set from time of day).
        save_reg: Write out output volume registration matrix.
        debug: Turn on debugging output.
        version: Print out version string and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriVol2volOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_VOL2VOL_METADATA)
    cargs = []
    cargs.append("mri_vol2vol")
    cargs.append(execution.input_file(movvol))
    cargs.append(execution.input_file(targvol))
    cargs.append(execution.input_file(outvol))
    if dispvol is not None:
        cargs.extend([
            "--disp",
            execution.input_file(dispvol)
        ])
    if downsample is not None:
        cargs.extend([
            "--downsample",
            *map(str, downsample)
        ])
    if register_dat is not None:
        cargs.extend([
            "--reg",
            execution.input_file(register_dat)
        ])
    if lta is not None:
        cargs.extend([
            "--lta",
            execution.input_file(lta)
        ])
    if lta_inv is not None:
        cargs.extend([
            "--lta-inv",
            execution.input_file(lta_inv)
        ])
    if fsl is not None:
        cargs.extend([
            "--fsl",
            execution.input_file(fsl)
        ])
    if xfm is not None:
        cargs.extend([
            "--xfm",
            execution.input_file(xfm)
        ])
    if inv:
        cargs.append("--inv")
    if tal:
        cargs.append("--tal")
    if talres is not None:
        cargs.extend([
            "--talres",
            str(talres)
        ])
    if talxfm is not None:
        cargs.extend([
            "--talxfm",
            execution.input_file(talxfm)
        ])
    if m3z is not None:
        cargs.extend([
            "--m3z",
            execution.input_file(m3z)
        ])
    if inv_morph:
        cargs.append("--inv-morph")
    if fstarg is not None:
        cargs.extend([
            "--fstarg",
            fstarg
        ])
    if crop is not None:
        cargs.extend([
            "--crop",
            str(crop)
        ])
    if slice_crop is not None:
        cargs.extend([
            "--slice-crop",
            *map(str, slice_crop)
        ])
    if slice_reverse:
        cargs.append("--slice-reverse")
    if slice_bias is not None:
        cargs.extend([
            "--slice-bias",
            str(slice_bias)
        ])
    if interp is not None:
        cargs.extend([
            "--interp",
            interp
        ])
    if fill_average:
        cargs.append("--fill-average")
    if fill_conserve:
        cargs.append("--fill-conserve")
    if fill_up is not None:
        cargs.extend([
            "--fill-upsample",
            str(fill_up)
        ])
    if mul is not None:
        cargs.extend([
            "--mul",
            str(mul)
        ])
    if precision is not None:
        cargs.extend([
            "--precision",
            precision
        ])
    if keep_precision:
        cargs.append("--keep-precision")
    if kernel:
        cargs.append("--kernel")
    if copy_ctab:
        cargs.append("--copy-ctab")
    if gcam is not None:
        cargs.extend([
            "--gcam",
            gcam
        ])
    if spm_warp is not None:
        cargs.extend([
            "--spm-warp",
            spm_warp
        ])
    if map_point is not None:
        cargs.extend([
            "--map-point",
            map_point
        ])
    if map_point_inv_lta is not None:
        cargs.extend([
            "--map-point-inv-lta",
            map_point_inv_lta
        ])
    if no_resample:
        cargs.append("--no-resample")
    if rot is not None:
        cargs.extend([
            "--rot",
            *map(str, rot)
        ])
    if trans is not None:
        cargs.extend([
            "--trans",
            *map(str, trans)
        ])
    if shear is not None:
        cargs.extend([
            "--shear",
            *map(str, shear)
        ])
    if reg_final is not None:
        cargs.extend([
            "--reg-final",
            execution.input_file(reg_final)
        ])
    if synth:
        cargs.append("--synth")
    if seed is not None:
        cargs.extend([
            "--seed",
            str(seed)
        ])
    if save_reg:
        cargs.append("--save-reg")
    if debug:
        cargs.append("--debug")
    if version:
        cargs.append("--version")
    ret = MriVol2volOutputs(
        root=execution.output_file("."),
        output_volume=execution.output_file(pathlib.Path(outvol).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_VOL2VOL_METADATA",
    "MriVol2volOutputs",
    "mri_vol2vol",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_TRANSMANTLE_DYSPLASIA_PATHS_METADATA = Metadata(
    id="effcf060042c53596ed252e67dbd78f3fd8cbd8e.boutiques",
    name="mris_transmantle_dysplasia_paths",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisTransmantleDysplasiaPathsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_transmantle_dysplasia_paths(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output volume file"""


def mris_transmantle_dysplasia_paths(
    surface: InputPathType,
    aseg_volume: InputPathType,
    intensity_volume: InputPathType,
    xform: InputPathType,
    output_volume: str,
    filter_: list[float] | None = None,
    noise_sensitivity: bool = False,
    runner: Runner | None = None,
) -> MrisTransmantleDysplasiaPathsOutputs:
    """
    Tool for transmantle dysplasia path computation.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        surface: Surface file.
        aseg_volume: ASEG volume file.
        intensity_volume: Intensity volume file.
        xform: Transformation file.
        output_volume: Output volume file.
        filter_: Apply specified filter with low and high values (not\
            implemented yet).
        noise_sensitivity: Noise-sensitivity normalize inverse (default=1).
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisTransmantleDysplasiaPathsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_TRANSMANTLE_DYSPLASIA_PATHS_METADATA)
    cargs = []
    cargs.append("mris_transmantle_dysplasia_paths")
    cargs.append(execution.input_file(surface))
    cargs.append(execution.input_file(aseg_volume))
    cargs.append(execution.input_file(intensity_volume))
    cargs.append(execution.input_file(xform))
    cargs.append(output_volume)
    if filter_ is not None:
        cargs.extend([
            "-f",
            *map(str, filter_)
        ])
    if noise_sensitivity:
        cargs.append("-n")
    ret = MrisTransmantleDysplasiaPathsOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_TRANSMANTLE_DYSPLASIA_PATHS_METADATA",
    "MrisTransmantleDysplasiaPathsOutputs",
    "mris_transmantle_dysplasia_paths",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_SBBR_METADATA = Metadata(
    id="f4b950626104a4845f82588892a8047d0782b10a.boutiques",
    name="mri_sbbr",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriSbbrOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_sbbr(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_sbbr(
    template_volume: InputPathType,
    surface_file: InputPathType,
    init_reg_file: InputPathType,
    t1: bool = False,
    t2: bool = False,
    optimization_type: float | None = None,
    distance_in: float | None = None,
    distance_out: float | None = None,
    slope: float | None = None,
    ftol: float | None = None,
    linmintol: float | None = None,
    niters_max: float | None = None,
    search: str | None = None,
    search1d: str | None = None,
    parameter_set: str | None = None,
    increment: float | None = None,
    slice_number: float | None = None,
    threads: float | None = None,
    output_registration: str | None = None,
    inverted_output_registration: str | None = None,
    output_surface: str | None = None,
    debug: bool = False,
    diagnostic: bool = False,
    check_options: bool = False,
    runner: Runner | None = None,
) -> MriSbbrOutputs:
    """
    Special implementation of boundary-based registration for a single slice.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        template_volume: Template volume file.
        surface_file: Surface file.
        init_reg_file: Initial registration file.
        t1: Use T1-weighted image.
        t2: Use T2-weighted image.
        optimization_type: Optimization type; choose 1, 2, or 3 (default is 1,\
            6 dof).
        distance_in: Distance in mm into surface (default 1.0).
        distance_out: Distance in mm out of surface (default 2.0).
        slope: BBR slope (default 0.5).
        ftol: Tolerance for fitting (default 1.000000e-08).
        linmintol: Linear minimization tolerance (default 0.0).
        niters_max: Maximum number of iterations (default 10).
        search: Brute force search through parameter space.
        search1d: 1D search through parameter space.
        parameter_set: Set initial parameter.
        increment: Face number increment (default 1).
        slice_number: Slice number (defaults to 0).
        threads: Number of threads.
        output_registration: Output registration file.
        inverted_output_registration: Inverted output registration file.
        output_surface: Output surface in slice coordinates.
        debug: Turn on debugging.
        diagnostic: Turn on diagnostics.
        check_options: Don't run anything, just check options and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriSbbrOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_SBBR_METADATA)
    cargs = []
    cargs.append("mri_sbbr")
    cargs.extend([
        "--mov",
        execution.input_file(template_volume)
    ])
    cargs.extend([
        "--surf",
        execution.input_file(surface_file)
    ])
    cargs.extend([
        "--init-reg",
        execution.input_file(init_reg_file)
    ])
    if t1:
        cargs.append("--t1")
    if t2:
        cargs.append("--t2")
    if optimization_type is not None:
        cargs.extend([
            "--opt",
            str(optimization_type)
        ])
    if distance_in is not None:
        cargs.extend([
            "--din",
            str(distance_in)
        ])
    if distance_out is not None:
        cargs.extend([
            "--dout",
            str(distance_out)
        ])
    if slope is not None:
        cargs.extend([
            "--slope",
            str(slope)
        ])
    if ftol is not None:
        cargs.extend([
            "--ftol",
            str(ftol)
        ])
    if linmintol is not None:
        cargs.extend([
            "--linmintol",
            str(linmintol)
        ])
    if niters_max is not None:
        cargs.extend([
            "--niters-max",
            str(niters_max)
        ])
    if search is not None:
        cargs.extend([
            "--search",
            search
        ])
    if search1d is not None:
        cargs.extend([
            "--search1d",
            search1d
        ])
    if parameter_set is not None:
        cargs.extend([
            "--p",
            parameter_set
        ])
    if increment is not None:
        cargs.extend([
            "--inc",
            str(increment)
        ])
    if slice_number is not None:
        cargs.extend([
            "--slice",
            str(slice_number)
        ])
    if threads is not None:
        cargs.extend([
            "--threads",
            str(threads)
        ])
    if output_registration is not None:
        cargs.extend([
            "--reg",
            output_registration
        ])
    if inverted_output_registration is not None:
        cargs.extend([
            "--reg-inv",
            inverted_output_registration
        ])
    if output_surface is not None:
        cargs.extend([
            "--out-surf",
            output_surface
        ])
    if debug:
        cargs.append("--debug")
    if diagnostic:
        cargs.append("--diag")
    if check_options:
        cargs.append("--checkopts")
    ret = MriSbbrOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_SBBR_METADATA",
    "MriSbbrOutputs",
    "mri_sbbr",
]



"""
NiftyReg

NiftyReg is an open-source software for efficient medical image registration. It
has been mainly developed by members of the Centre for Medical Image Computing
at University College London, UK.

URL: http://cmictig.cs.ucl.ac.uk/wiki/index.php/NiftyReg
"""
# This file was auto generated by Styx.
# Do not edit this file directly.

from .reg_aladin import *
from .reg_average import *
from .reg_f3d import *
from .reg_jacobian import *
from .reg_resample import *
from .reg_tools import *
from .reg_transform import *



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

SIENA_CAL_METADATA = Metadata(
    id="242ef49e28319c61f6a5f6ae2b1dfc3ffd7f393f.boutiques",
    name="siena_cal",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class SienaCalOutputs(typing.NamedTuple):
    """
    Output object returned when calling `siena_cal(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_dir: OutputPathType
    """Output directory containing SIENA results"""


def siena_cal(
    input1_file: InputPathType,
    input2_file: InputPathType,
    scale: float,
    siena_diff_options: str | None = None,
    runner: Runner | None = None,
) -> SienaCalOutputs:
    """
    SIENA is part of FSL (FMRIB Software Library), which performs a two-timepoint
    brain volume change analysis.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        input1_file: First input image file root (e.g., baseline image root).
        input2_file: Second input image file root (e.g., follow-up image root).
        scale: Voxel size scaling factor.
        siena_diff_options: Optional SIENA difference options.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `SienaCalOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(SIENA_CAL_METADATA)
    cargs = []
    cargs.append("siena_cal")
    cargs.append(execution.input_file(input1_file))
    cargs.append(execution.input_file(input2_file))
    cargs.append(str(scale))
    if siena_diff_options is not None:
        cargs.append(siena_diff_options)
    ret = SienaCalOutputs(
        root=execution.output_file("."),
        output_dir=execution.output_file(pathlib.Path(input1_file).name + "_to_" + pathlib.Path(input2_file).name + "_siena"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "SIENA_CAL_METADATA",
    "SienaCalOutputs",
    "siena_cal",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_GCA_AMBIGUOUS_METADATA = Metadata(
    id="8e1f7ad27bb8e2945f700929ab50960c8ad52f74.boutiques",
    name="mri_gca_ambiguous",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriGcaAmbiguousOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_gca_ambiguous(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_image: OutputPathType
    """Resulting MR image file with computed ambiguity measure"""


def mri_gca_ambiguous(
    gca_file: InputPathType,
    output_volume: InputPathType,
    runner: Runner | None = None,
) -> MriGcaAmbiguousOutputs:
    """
    This program computes an ambiguity measure across a GCA and outputs an MR image
    of it.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        gca_file: The input GCA file.
        output_volume: The output MR image file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriGcaAmbiguousOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_GCA_AMBIGUOUS_METADATA)
    cargs = []
    cargs.append("mri_gca_ambiguous")
    cargs.append(execution.input_file(gca_file))
    cargs.append(execution.input_file(output_volume))
    ret = MriGcaAmbiguousOutputs(
        root=execution.output_file("."),
        output_image=execution.output_file(pathlib.Path(output_volume).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_GCA_AMBIGUOUS_METADATA",
    "MriGcaAmbiguousOutputs",
    "mri_gca_ambiguous",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FABBER_CEST_METADATA = Metadata(
    id="02b8cdea1646edd376c3e6590fd5b1de7b4522ff.boutiques",
    name="fabber_cest",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FabberCestOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fabber_cest(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    logfile: OutputPathType
    """Log file"""
    modelfit_out: OutputPathType
    """Model fit output as a 4d volume"""
    residuals_out: OutputPathType
    """Residuals output as a 4d volume"""
    modelextras_out: OutputPathType
    """Model extras output"""
    mvn_out: OutputPathType
    """Final MVN distributions output"""
    mean_out: OutputPathType
    """Parameter means output"""
    std_out: OutputPathType
    """Parameter standard deviations output"""
    var_out: OutputPathType
    """Parameter variances output"""
    zstat_out: OutputPathType
    """Parameter Z statistics output"""
    noise_mean_out: OutputPathType
    """Noise means output"""
    noise_std_out: OutputPathType
    """Noise standard deviations output"""
    free_energy_out: OutputPathType
    """Free energy output"""


def fabber_cest(
    runner: Runner | None = None,
) -> FabberCestOutputs:
    """
    Fabber Model-based Analysis.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FabberCestOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FABBER_CEST_METADATA)
    cargs = []
    cargs.append("fabber_cest")
    cargs.append("[--<option>")
    cargs.append("|")
    cargs.append("--<option>=<value>")
    cargs.append("...]")
    ret = FabberCestOutputs(
        root=execution.output_file("."),
        logfile=execution.output_file("[OUTPUT]/logfile.log"),
        modelfit_out=execution.output_file("[OUTPUT]/model_fit.nii.gz"),
        residuals_out=execution.output_file("[OUTPUT]/residuals.nii.gz"),
        modelextras_out=execution.output_file("[OUTPUT]/model_extras.nii.gz"),
        mvn_out=execution.output_file("[OUTPUT]/mvn.nii.gz"),
        mean_out=execution.output_file("[OUTPUT]/mean.nii.gz"),
        std_out=execution.output_file("[OUTPUT]/std.nii.gz"),
        var_out=execution.output_file("[OUTPUT]/var.nii.gz"),
        zstat_out=execution.output_file("[OUTPUT]/zstat.nii.gz"),
        noise_mean_out=execution.output_file("[OUTPUT]/noise_mean.nii.gz"),
        noise_std_out=execution.output_file("[OUTPUT]/noise_std.nii.gz"),
        free_energy_out=execution.output_file("[OUTPUT]/free_energy.nii.gz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FABBER_CEST_METADATA",
    "FabberCestOutputs",
    "fabber_cest",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

ROI2DATASET_METADATA = Metadata(
    id="5ce644f007ce2ecc979c958450e6f9ce7de594be.boutiques",
    name="ROI2dataset",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class Roi2datasetOutputs(typing.NamedTuple):
    """
    Output object returned when calling `roi2dataset(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def roi2dataset(
    prefix: str,
    input_rois: list[InputPathType],
    keep_separate: bool = False,
    nodelist: str | None = None,
    nodelist_nodups: str | None = None,
    nodelist_with_roival: bool = False,
    label_dset: str | None = None,
    output_format: str | None = None,
    domain_parent_id: str | None = None,
    pad_to_node: float | None = None,
    pad_label: float | None = None,
    runner: Runner | None = None,
) -> Roi2datasetOutputs:
    """
    Transforms a series of ROI files to a node dataset.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        prefix: Prefix of output dataset.
        input_rois: ROI files to turn into a data set (space-separated list).\
            This parameter MUST be the last one on command line.
        keep_separate: Output one column (sub-brick) for each ROI value.
        nodelist: Prefix for a set of .1D files that contain a list of node\
            indices in the order they appear in an ROI.
        nodelist_nodups: Prefix for a set of .1D files that contain a list of\
            node indices in the order they appear in an ROI, with duplicate nodes\
            removed.
        nodelist_with_roival: Also add the ROI value as a second column in .1D\
            files output by -nodelist.
        label_dset: Write a label dataset instead of a simple dataset. Sets\
            output format to NIML.
        output_format: Output format of dataset. One of: ni_bi, ni_as, 1D.
        domain_parent_id: Idcode of domain parent. Only ROIs with the same\
            domain parent are included in the output.
        pad_to_node: Output a full dataset from node 0 to node max_index (total\
            of max_index + 1 nodes).
        pad_label: Use padding_label (an integer) to label nodes not part of\
            any ROI. Default is 0.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `Roi2datasetOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(ROI2DATASET_METADATA)
    cargs = []
    cargs.append("ROI2dataset")
    cargs.extend([
        "-prefix",
        prefix
    ])
    cargs.extend([execution.input_file(f) for f in input_rois])
    if keep_separate:
        cargs.append("-keep_separate")
    if nodelist is not None:
        cargs.extend([
            "-nodelist",
            nodelist
        ])
    if nodelist_nodups is not None:
        cargs.extend([
            "-nodelist.nodups",
            nodelist_nodups
        ])
    if nodelist_with_roival:
        cargs.append("-nodelist_with_ROIval")
    if label_dset is not None:
        cargs.extend([
            "-label_dset",
            label_dset
        ])
    if output_format is not None:
        cargs.extend([
            "-of",
            output_format
        ])
    if domain_parent_id is not None:
        cargs.extend([
            "-dom_par_id",
            domain_parent_id
        ])
    if pad_to_node is not None:
        cargs.extend([
            "-pad_to_node",
            str(pad_to_node)
        ])
    if pad_label is not None:
        cargs.extend([
            "-pad_label",
            str(pad_label)
        ])
    ret = Roi2datasetOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "ROI2DATASET_METADATA",
    "Roi2datasetOutputs",
    "roi2dataset",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RTFEEDME_METADATA = Metadata(
    id="32964e0c08bfc25e6c4f6eca5347bfc95b91dd98.boutiques",
    name="rtfeedme",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class RtfeedmeOutputs(typing.NamedTuple):
    """
    Output object returned when calling `rtfeedme(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def rtfeedme(
    datasets: list[InputPathType],
    host: str | None = None,
    interval_ms: float | None = None,
    send_3d: bool = False,
    buffer_mb: float | None = None,
    verbose: bool = False,
    swap_bytes: bool = False,
    nz_fake: float | None = None,
    drive_cmd: list[str] | None = None,
    note: list[str] | None = None,
    yrange: float | None = None,
    runner: Runner | None = None,
) -> RtfeedmeOutputs:
    """
    Test the real-time plugin by sending all the bricks in 'dataset' to AFNI.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        datasets: List of datasets to send to AFNI, specified as paths to\
            dataset files. Multiple datasets can be specified.
        host: Send data via TCP/IP to AFNI running on the specified computer\
            system 'sname'. Default is the current system using shared memory. Use\
            'localhost' to send on the current system using TCP/IP.
        interval_ms: Inter-transmit interval in milliseconds. Default is to\
            send data as fast as possible.
        send_3d: Send data in 3D bricks. Default is 2D slices.
        buffer_mb: Set the interprocess communications buffer size in megabytes\
            when using shared memory. Has no effect if using TCP/IP. Default is 1\
            MB; if set to 0, a 50 KB buffer is used.
        verbose: Be talkative about actions.
        swap_bytes: Swap byte pairs before sending data.
        nz_fake: Send 'nz' as the value of nzz for debugging purposes.
        drive_cmd: Send 'cmd' as a DRIVE_AFNI command. If 'cmd' contains\
            spaces, it must be quoted. Multiple -drive options can be used.
        note: Send 'sss' as a NOTE to the realtime plugin. Multiple -note\
            options can be used.
        yrange: Send value 'v' as the y-range for realtime motion estimation\
            graphing.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RtfeedmeOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RTFEEDME_METADATA)
    cargs = []
    cargs.append("rtfeedme")
    cargs.extend([execution.input_file(f) for f in datasets])
    if host is not None:
        cargs.extend([
            "-host",
            host
        ])
    if interval_ms is not None:
        cargs.extend([
            "-dt",
            str(interval_ms)
        ])
    if send_3d:
        cargs.append("-3D")
    if buffer_mb is not None:
        cargs.extend([
            "-buf",
            str(buffer_mb)
        ])
    if verbose:
        cargs.append("-verbose")
    if swap_bytes:
        cargs.append("-swap2")
    if nz_fake is not None:
        cargs.extend([
            "-nzfake",
            str(nz_fake)
        ])
    if drive_cmd is not None:
        cargs.extend([
            "-drive",
            *drive_cmd
        ])
    if note is not None:
        cargs.extend([
            "-note",
            *note
        ])
    if yrange is not None:
        cargs.extend([
            "-gyr",
            str(yrange)
        ])
    ret = RtfeedmeOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RTFEEDME_METADATA",
    "RtfeedmeOutputs",
    "rtfeedme",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DIMON_METADATA = Metadata(
    id="47141d28c3f7ccd9b2aa834d602f55feeab89023.boutiques",
    name="Dimon",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class DimonOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dimon(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    sorted_files: OutputPathType
    """Sorted input files with specified prefix"""
    sorted_files_details: OutputPathType | None
    """Details about sorted files"""


def dimon(
    infile_prefix: str,
    infile_pattern: str | None = None,
    infile_list: InputPathType | None = None,
    rt_cmd: str | None = None,
    host: str | None = None,
    drive_afni: str | None = None,
    drive_wait: str | None = None,
    te_list: str | None = None,
    sort_method: str | None = None,
    runner: Runner | None = None,
) -> DimonOutputs:
    """
    Monitor real-time acquisition of DICOM image files.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        infile_prefix: Prefix matching input files.
        infile_pattern: Pattern for input files.
        infile_list: List of filenames.
        rt_cmd: Send COMMAND(s) to realtime plugin.
        host: Specify the host for afni communication.
        drive_afni: Send 'drive afni' command, CMND.
        drive_wait: Send delayed 'drive afni' command, CMND.
        te_list: Specify a list of echo times.
        sort_method: Apply sorting method to image structures.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DimonOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DIMON_METADATA)
    cargs = []
    cargs.append("Dimon")
    cargs.extend([
        "-infile_prefix",
        infile_prefix
    ])
    if infile_pattern is not None:
        cargs.extend([
            "-infile_pattern",
            infile_pattern
        ])
    if infile_list is not None:
        cargs.extend([
            "-infile_list",
            execution.input_file(infile_list)
        ])
    if rt_cmd is not None:
        cargs.extend([
            "-rt_cmd",
            rt_cmd
        ])
    if host is not None:
        cargs.extend([
            "-host",
            host
        ])
    if drive_afni is not None:
        cargs.extend([
            "-drive_afni",
            drive_afni
        ])
    if drive_wait is not None:
        cargs.extend([
            "-drive_wait",
            drive_wait
        ])
    if te_list is not None:
        cargs.extend([
            "-te_list",
            te_list
        ])
    if sort_method is not None:
        cargs.extend([
            "-sort_method",
            sort_method
        ])
    ret = DimonOutputs(
        root=execution.output_file("."),
        sorted_files=execution.output_file(infile_prefix + "*"),
        sorted_files_details=execution.output_file(pathlib.Path(infile_list).name + "_details") if (infile_list is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DIMON_METADATA",
    "DimonOutputs",
    "dimon",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSL_DEFACE_METADATA = Metadata(
    id="df142ae527dbfb0cc6fa0cc6e7112d7cda842d70.boutiques",
    name="fsl_deface",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslDefaceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fsl_deface(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outfile: OutputPathType
    """Defaced T1w image"""
    out_defacing_mask: OutputPathType | None
    """Defacing mask file"""
    out_cropped_struc: OutputPathType | None
    """Cropped structural image file"""
    out_orig_to_std_mat: OutputPathType | None
    """Affine matrix from original struct to std"""
    out_orig_to_cropped_mat: OutputPathType | None
    """Affine matrix from original struct to cropped struct"""
    out_cropped_to_std_mat: OutputPathType | None
    """Affine matrix from cropped struct to std"""
    qc_image_original: OutputPathType | None
    """QC image for defacing (original)"""
    qc_image_cropped: OutputPathType | None
    """QC image for defacing (cropped)"""


def fsl_deface(
    infile: InputPathType,
    outfile: str,
    cropped_defacing_flag: bool = False,
    defacing_mask: str | None = None,
    cropped_struc: str | None = None,
    orig_to_std_mat: str | None = None,
    orig_to_cropped_mat: str | None = None,
    cropped_to_std_mat: str | None = None,
    shift_nud: list[float] | None = None,
    fractional_intensity: float | None = None,
    bias_correct_flag: bool = False,
    center_of_gravity: list[float] | None = None,
    qc_images: str | None = None,
    runner: Runner | None = None,
) -> FslDefaceOutputs:
    """
    Tool to deface a structural T1w image.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        infile: Input T1w image.
        outfile: Output defaced T1w image.
        cropped_defacing_flag: Apply the defacing to the cropped image instead\
            of the original image.
        defacing_mask: Filename to save the defacing mask.
        cropped_struc: Filename to save the new cropped struct.
        orig_to_std_mat: Filename to save affine matrix from original struct to\
            std.
        orig_to_cropped_mat: Filename to save affine matrix from original\
            struct to cropped struct.
        cropped_to_std_mat: Filename to save affine matrix from cropped struct\
            to std.
        shift_nud: Shift, in mm, x-, y- and z-directions, to shift face mask by\
            (These matrices will only work if the input has been previously\
            reoriented to std).
        fractional_intensity: Fractional intensity for bet (0->1); default=0.5.
        bias_correct_flag: Bias-correct the input image (with fast).
        center_of_gravity: Center-of-gravity for bet (voxels, not mm).
        qc_images: Generate 2 pngs to show how the defacing worked for QC\
            purposes.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslDefaceOutputs`).
    """
    if fractional_intensity is not None and not (0 <= fractional_intensity <= 1): 
        raise ValueError(f"'fractional_intensity' must be between 0 <= x <= 1 but was {fractional_intensity}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSL_DEFACE_METADATA)
    cargs = []
    cargs.append("fsl_deface")
    cargs.append(execution.input_file(infile))
    cargs.append(outfile)
    if cropped_defacing_flag:
        cargs.append("-k")
    if defacing_mask is not None:
        cargs.extend([
            "-d",
            defacing_mask
        ])
    if cropped_struc is not None:
        cargs.extend([
            "-n",
            cropped_struc
        ])
    if orig_to_std_mat is not None:
        cargs.extend([
            "-m13",
            orig_to_std_mat
        ])
    if orig_to_cropped_mat is not None:
        cargs.extend([
            "-m12",
            orig_to_cropped_mat
        ])
    if cropped_to_std_mat is not None:
        cargs.extend([
            "-m23",
            cropped_to_std_mat
        ])
    if shift_nud is not None:
        cargs.extend([
            "-nud",
            *map(str, shift_nud)
        ])
    if fractional_intensity is not None:
        cargs.extend([
            "-f",
            str(fractional_intensity)
        ])
    if bias_correct_flag:
        cargs.append("-B")
    if center_of_gravity is not None:
        cargs.extend([
            "-c",
            *map(str, center_of_gravity)
        ])
    if qc_images is not None:
        cargs.extend([
            "-p",
            qc_images
        ])
    ret = FslDefaceOutputs(
        root=execution.output_file("."),
        outfile=execution.output_file(outfile + ".nii.gz"),
        out_defacing_mask=execution.output_file(defacing_mask + ".nii.gz") if (defacing_mask is not None) else None,
        out_cropped_struc=execution.output_file(cropped_struc + ".nii.gz") if (cropped_struc is not None) else None,
        out_orig_to_std_mat=execution.output_file(orig_to_std_mat + ".mat") if (orig_to_std_mat is not None) else None,
        out_orig_to_cropped_mat=execution.output_file(orig_to_cropped_mat + ".mat") if (orig_to_cropped_mat is not None) else None,
        out_cropped_to_std_mat=execution.output_file(cropped_to_std_mat + ".mat") if (cropped_to_std_mat is not None) else None,
        qc_image_original=execution.output_file(qc_images + "_defaced_original.png") if (qc_images is not None) else None,
        qc_image_cropped=execution.output_file(qc_images + "_defaced_cropped.png") if (qc_images is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSL_DEFACE_METADATA",
    "FslDefaceOutputs",
    "fsl_deface",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

HELP_FORMAT_METADATA = Metadata(
    id="2c2e44d1845d44d18c53666d3810111107853205.boutiques",
    name="help_format",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class HelpFormatOutputs(typing.NamedTuple):
    """
    Output object returned when calling `help_format(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    formatted_output: OutputPathType
    """The formatted text with hyperlinks"""


def help_format(
    stdin: str,
    runner: Runner | None = None,
) -> HelpFormatOutputs:
    """
    Formats text by converting URLs into HTML hyperlinks.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        stdin: Standard input text to be formatted.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `HelpFormatOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(HELP_FORMAT_METADATA)
    cargs = []
    cargs.append("help_format")
    cargs.append(stdin)
    ret = HelpFormatOutputs(
        root=execution.output_file("."),
        formatted_output=execution.output_file("formatted_output.html"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "HELP_FORMAT_METADATA",
    "HelpFormatOutputs",
    "help_format",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_FUSE_INTENSITY_IMAGES_METADATA = Metadata(
    id="b44314c2289888a92cbc6fcb500d2dc0bdb27bc9.boutiques",
    name="mri_fuse_intensity_images",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriFuseIntensityImagesOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_fuse_intensity_images(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    fused_intensity_image: OutputPathType
    """The resulting fused intensity image"""


def mri_fuse_intensity_images(
    longitudinal_time_point_file: InputPathType,
    input_volume: InputPathType,
    transform_file: InputPathType,
    output_volume: InputPathType,
    runner: Runner | None = None,
) -> MriFuseIntensityImagesOutputs:
    """
    Fuses intensity images based on given transforms.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        longitudinal_time_point_file: File containing the longitudinal time\
            points.
        input_volume: Input volume to be fused.
        transform_file: File containing the transforms.
        output_volume: Output fused volume.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriFuseIntensityImagesOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_FUSE_INTENSITY_IMAGES_METADATA)
    cargs = []
    cargs.append("mri_fuse_intensity_images")
    cargs.append(execution.input_file(longitudinal_time_point_file))
    cargs.append(execution.input_file(input_volume))
    cargs.append(execution.input_file(transform_file))
    cargs.append(execution.input_file(output_volume))
    ret = MriFuseIntensityImagesOutputs(
        root=execution.output_file("."),
        fused_intensity_image=execution.output_file(pathlib.Path(output_volume).name),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_FUSE_INTENSITY_IMAGES_METADATA",
    "MriFuseIntensityImagesOutputs",
    "mri_fuse_intensity_images",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CLUST_EXP_HIST_TABLE_PY_METADATA = Metadata(
    id="a706e0c184974ad6ed86360994f032d1d4e5296f.boutiques",
    name="ClustExp_HistTable.py",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class ClustExpHistTablePyOutputs(typing.NamedTuple):
    """
    Output object returned when calling `clust_exp_hist_table_py(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    group_table: OutputPathType | None
    """Table with information parsed from the statistics dataset history."""


def clust_exp_hist_table_py(
    stat_dset: InputPathType,
    prefix: str | None = None,
    session: str | None = None,
    overwrite: bool = False,
    runner: Runner | None = None,
) -> ClustExpHistTablePyOutputs:
    """
    Script to extract the data table from history of datasets from 3dttest++, 3dMVM,
    or 3dLME.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        stat_dset: Statistics dataset.
        prefix: Name for output (no path). Default is GroupOut.
        session: Output parent folder if you don't want the current working\
            directory. Default is ./.
        overwrite: Remove previous folder with same PREFIX.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ClustExpHistTablePyOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CLUST_EXP_HIST_TABLE_PY_METADATA)
    cargs = []
    cargs.append("ClustExp_HistTable.py")
    cargs.extend([
        "-StatDSET",
        execution.input_file(stat_dset)
    ])
    if prefix is not None:
        cargs.extend([
            "-prefix",
            prefix
        ])
    if session is not None:
        cargs.extend([
            "-session",
            session
        ])
    if overwrite:
        cargs.append("-overwrite")
    ret = ClustExpHistTablePyOutputs(
        root=execution.output_file("."),
        group_table=execution.output_file(prefix + "_GroupTable.csv") if (prefix is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CLUST_EXP_HIST_TABLE_PY_METADATA",
    "ClustExpHistTablePyOutputs",
    "clust_exp_hist_table_py",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

INFLATE_SUBJECT_NEW_LH_METADATA = Metadata(
    id="08307c12a50c2ff8603980e07c1bcf6e9a16f2e1.boutiques",
    name="inflate_subject_new-lh",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class InflateSubjectNewLhOutputs(typing.NamedTuple):
    """
    Output object returned when calling `inflate_subject_new_lh(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    inflated_surface: OutputPathType
    """Inflated surface file for the left hemisphere"""


def inflate_subject_new_lh(
    subject_dir: str,
    runner: Runner | None = None,
) -> InflateSubjectNewLhOutputs:
    """
    Tool for inflating the left hemisphere of a subject in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subject_dir: Directory of the subject's data in FreeSurfer.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `InflateSubjectNewLhOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(INFLATE_SUBJECT_NEW_LH_METADATA)
    cargs = []
    cargs.extend([
        "-lh",
        "inflate_subject_new" + subject_dir
    ])
    cargs.append("[OPTIONS]")
    ret = InflateSubjectNewLhOutputs(
        root=execution.output_file("."),
        inflated_surface=execution.output_file(subject_dir + "/surf/lh.inflated"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "INFLATE_SUBJECT_NEW_LH_METADATA",
    "InflateSubjectNewLhOutputs",
    "inflate_subject_new_lh",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__MEASURE_EROSION_THICK_METADATA = Metadata(
    id="80ee03f3fb5d8279762f2ef41bc06131e413b576.boutiques",
    name="@measure_erosion_thick",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VMeasureErosionThickOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__measure_erosion_thick(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    erosion_depth: OutputPathType
    """Depth dataset."""
    erosion_thick: OutputPathType
    """Volumetric thickness dataset."""
    erosion_thick_smooth: OutputPathType
    """Smoothed volumetric thickness dataset."""
    erosion_thick_niml: OutputPathType
    """Unsmoothed thickness mapped to surface nodes."""
    erosion_thick_smooth_niml: OutputPathType
    """Smoothed thickness mapped to surface nodes."""
    maskset_output: OutputPathType
    """Mask dataset."""
    resampled_maskset: OutputPathType
    """Resampled mask dataset."""
    anat_gii: OutputPathType
    """Surface representation of mask volume."""
    quick_spec: OutputPathType
    """Simple specification file for surface to use with suma commands."""


def v__measure_erosion_thick(
    maskset: InputPathType,
    surfset: InputPathType,
    outdir: str | None = None,
    resample: str | None = None,
    surfsmooth: float | None = None,
    smoothmm: float | None = None,
    maxthick: float | None = None,
    depthsearch: float | None = None,
    keep_temp_files: bool = False,
    surfsmooth_method: str | None = None,
    runner: Runner | None = None,
) -> VMeasureErosionThickOutputs:
    """
    Compute thickness of mask using erosion method.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        maskset: Mask dataset for input.
        surfset: Surface dataset onto which to map thickness (probably a\
            pial/gray matter surface).
        outdir: Output directory. If not specified, erosion_thickdir is used.
        resample: Resample input to mm in millimeters (put a number here).\
            Recommended for most 1mm data.
        surfsmooth: Smooth surface map of thickness by mm millimeters. Default\
            is 8 mm.
        smoothmm: Smooth volume by mm FWHM in mask. Default is 2*voxelsize of\
            mask or resampled mask.
        maxthick: Search for maximum thickness value of mm millimeters. Default\
            is 6 mm.
        depthsearch: Map to surface by looking for max along mm millimeter\
            normal vectors. Default is 3 mm.
        keep_temp_files: Do not delete the intermediate files (for testing).
        surfsmooth_method: Heat method used for smoothing surfaces. Default is\
            HEAT_07 but HEAT_05 is also useful for models.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VMeasureErosionThickOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__MEASURE_EROSION_THICK_METADATA)
    cargs = []
    cargs.append("@measure_erosion_thick")
    cargs.extend([
        "-maskset",
        execution.input_file(maskset)
    ])
    cargs.extend([
        "-surfset",
        execution.input_file(surfset)
    ])
    if outdir is not None:
        cargs.extend([
            "-outdir",
            outdir
        ])
    if resample is not None:
        cargs.extend([
            "-resample",
            resample
        ])
    if surfsmooth is not None:
        cargs.extend([
            "-surfsmooth",
            str(surfsmooth)
        ])
    if smoothmm is not None:
        cargs.extend([
            "-smoothmm",
            str(smoothmm)
        ])
    if maxthick is not None:
        cargs.extend([
            "-maxthick",
            str(maxthick)
        ])
    if depthsearch is not None:
        cargs.extend([
            "-depthsearch",
            str(depthsearch)
        ])
    if keep_temp_files:
        cargs.append("-keep_temp_files")
    if surfsmooth_method is not None:
        cargs.extend([
            "-surfsmooth_method",
            surfsmooth_method
        ])
    ret = VMeasureErosionThickOutputs(
        root=execution.output_file("."),
        erosion_depth=execution.output_file("erosion_depth.nii.gz"),
        erosion_thick=execution.output_file("erosion_thick.nii.gz"),
        erosion_thick_smooth=execution.output_file("erosion_thick_smooth.nii.gz"),
        erosion_thick_niml=execution.output_file("erosion_thick.niml.dset"),
        erosion_thick_smooth_niml=execution.output_file("erosion_thick_smooth_nn_mm.niml.dset"),
        maskset_output=execution.output_file("maskset.nii.gz"),
        resampled_maskset=execution.output_file("maskset_rs.nii.gz"),
        anat_gii=execution.output_file("anat.gii"),
        quick_spec=execution.output_file("quick.spec"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VMeasureErosionThickOutputs",
    "V__MEASURE_EROSION_THICK_METADATA",
    "v__measure_erosion_thick",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FAT_PROC_DWI_TO_DT_METADATA = Metadata(
    id="c5a2942f4ac3b0a68c89864b914dd62d776684d1.boutiques",
    name="fat_proc_dwi_to_dt",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class FatProcDwiToDtOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fat_proc_dwi_to_dt(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_files: OutputPathType
    """Output files generated with the specified prefix."""


def fat_proc_dwi_to_dt(
    in_dwi: InputPathType,
    in_gradmat: InputPathType,
    prefix: str,
    in_bvals: InputPathType | None = None,
    mask: InputPathType | None = None,
    mask_from_struc: bool = False,
    in_struc_res: InputPathType | None = None,
    in_ref_orig: InputPathType | None = None,
    prefix_dti: str | None = None,
    flip_x: bool = False,
    flip_y: bool = False,
    flip_z: bool = False,
    no_flip: bool = False,
    no_scale_out_1000: bool = False,
    no_reweight: bool = False,
    no_cumulative_wts: bool = False,
    qc_fa_thr: float | None = None,
    qc_fa_max: float | None = None,
    qc_fa_unc_max: float | None = None,
    qc_v12_unc_max: float | None = None,
    qc_prefix: str | None = None,
    no_qc_view: bool = False,
    no_cmd_out: bool = False,
    workdir: str | None = None,
    no_clean: bool = False,
    uncert_off: bool = False,
    uncert_iters: float | None = None,
    uncert_extra_cmds: str | None = None,
    check_abs_min: float | None = None,
    runner: Runner | None = None,
) -> FatProcDwiToDtOutputs:
    """
    This program fits tensors and DT parameters, as well as the uncertainty of DT
    parameters needed for tractography.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        in_dwi: 4D volume of N DWIs. Required.
        in_gradmat: Input text file of N gradient vectors or bmatrices.
        prefix: Set prefix for output DWI data.
        in_bvals: Optional, if bvalue information is in a separate file from\
            the b-vectors or matrices.
        mask: Optional whole brain mask can be input; otherwise, automasking is\
            performed.
        mask_from_struc: Flag to make a mask using 3dSkullStrip+3dmask_tool\
            from the structural file.
        in_struc_res: Alignment of the output DWI to the REF data set via\
            anatomical reference; a version of the anatomical that has been\
            resampled to match the DWI set.
        in_ref_orig: Use another data set to adjust the DWI and subsequent\
            parameter dsets' orientation and origin.
        prefix_dti: Set prefix for output DTI data; default is 'dt'. Do not\
            include path information here.
        flip_x: Flip the DW gradients in the x-direction.
        flip_y: Flip the DW gradients in the y-direction.
        flip_z: Flip the DW gradients in the z-direction.
        no_flip: Do not flip the DW gradients.
        no_scale_out_1000: Turn off scaling of physical length units by 1000\
            for tensor fitting.
        no_reweight: Turn off reweighting and refitting of tensors during\
            estimation.
        no_cumulative_wts: Turn off displaying overall weight factors for each\
            gradient.
        qc_fa_thr: Set threshold for overlay FA volume in QC image.
        qc_fa_max: Set cbar max for overlay FA volume in QC image.
        qc_fa_unc_max: Set cbar max for overlay uncertainty (stdev) of FA in QC\
            image.
        qc_v12_unc_max: Set cbar max for overlay uncertainty (stdev) of V1\
            towards V2 direction for DTs in QC image.
        qc_prefix: Set the prefix of the QC image files separately.
        no_qc_view: Turn off generating QC image files.
        no_cmd_out: Don't save the command line call of this program and the\
            location where it was run.
        workdir: Specify a working directory, which can be removed.
        no_clean: Do not remove the working directory.
        uncert_off: Don't perform uncertainty calculation.
        uncert_iters: Set the number of Monte Carlo iterations for the\
            uncertainty calculation (default: 300).
        uncert_extra_cmds: Extra commands for the uncertainty calculations.
        check_abs_min: Help the program push through finding tiny negative\
            values in columns that should contain numbers >=0. Provide a tolerance\
            value VVV.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FatProcDwiToDtOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FAT_PROC_DWI_TO_DT_METADATA)
    cargs = []
    cargs.append("fat_proc_dwi_to_dt")
    cargs.append(execution.input_file(in_dwi))
    cargs.extend([
        "-in_col_matA | -in_col_matT | -in_col_vec | -in_row_vec",
        execution.input_file(in_gradmat)
    ])
    cargs.extend([
        "-prefix",
        prefix
    ])
    if in_bvals is not None:
        cargs.extend([
            "-in_bvals",
            execution.input_file(in_bvals)
        ])
    if mask is not None:
        cargs.extend([
            "-mask",
            execution.input_file(mask)
        ])
    if mask_from_struc:
        cargs.append("-mask_from_struc")
    if in_struc_res is not None:
        cargs.extend([
            "-in_struc_res",
            execution.input_file(in_struc_res)
        ])
    if in_ref_orig is not None:
        cargs.extend([
            "-in_ref_orig",
            execution.input_file(in_ref_orig)
        ])
    if prefix_dti is not None:
        cargs.extend([
            "-prefix_dti",
            prefix_dti
        ])
    if flip_x:
        cargs.append("-flip_x")
    if flip_y:
        cargs.append("-flip_y")
    if flip_z:
        cargs.append("-flip_z")
    if no_flip:
        cargs.append("-no_flip")
    if no_scale_out_1000:
        cargs.append("-no_scale_out_1000")
    if no_reweight:
        cargs.append("-no_reweight")
    if no_cumulative_wts:
        cargs.append("-no_cumulative_wts")
    if qc_fa_thr is not None:
        cargs.extend([
            "-qc_fa_thr",
            str(qc_fa_thr)
        ])
    if qc_fa_max is not None:
        cargs.extend([
            "-qc_fa_max",
            str(qc_fa_max)
        ])
    if qc_fa_unc_max is not None:
        cargs.extend([
            "-qc_fa_unc_max",
            str(qc_fa_unc_max)
        ])
    if qc_v12_unc_max is not None:
        cargs.extend([
            "-qc_v12_unc_max",
            str(qc_v12_unc_max)
        ])
    if qc_prefix is not None:
        cargs.extend([
            "-qc_prefix",
            qc_prefix
        ])
    if no_qc_view:
        cargs.append("-no_qc_view")
    if no_cmd_out:
        cargs.append("-no_cmd_out")
    if workdir is not None:
        cargs.extend([
            "-workdir",
            workdir
        ])
    if no_clean:
        cargs.append("-no_clean")
    if uncert_off:
        cargs.append("-uncert_off")
    if uncert_iters is not None:
        cargs.extend([
            "-uncert_iters",
            str(uncert_iters)
        ])
    if uncert_extra_cmds is not None:
        cargs.extend([
            "-uncert_extra_cmds",
            uncert_extra_cmds
        ])
    if check_abs_min is not None:
        cargs.extend([
            "-check_abs_min",
            str(check_abs_min)
        ])
    ret = FatProcDwiToDtOutputs(
        root=execution.output_file("."),
        output_files=execution.output_file(prefix + "*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FAT_PROC_DWI_TO_DT_METADATA",
    "FatProcDwiToDtOutputs",
    "fat_proc_dwi_to_dt",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_REDUCE_METADATA = Metadata(
    id="cf6964a089f9810b1107cc8ec31b854f370cd7e4.boutiques",
    name="mri_reduce",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriReduceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_reduce(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    reduced_output: OutputPathType
    """Reduced MRI file output"""


def mri_reduce(
    input_file: InputPathType,
    output_file: str,
    runner: Runner | None = None,
) -> MriReduceOutputs:
    """
    A tool to reduce MRI file dimensions.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_file: Input MRI file.
        output_file: Output filename for the reduced MRI file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriReduceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_REDUCE_METADATA)
    cargs = []
    cargs.append("mri_reduce")
    cargs.append(execution.input_file(input_file))
    cargs.append(output_file)
    ret = MriReduceOutputs(
        root=execution.output_file("."),
        reduced_output=execution.output_file(output_file),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_REDUCE_METADATA",
    "MriReduceOutputs",
    "mri_reduce",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

AFNI_OPEN_METADATA = Metadata(
    id="011cf64aad17ae870a6340e6c6714d18cd8c6e43.boutiques",
    name="afni_open",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class AfniOpenOutputs(typing.NamedTuple):
    """
    Output object returned when calling `afni_open(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def afni_open(
    files: list[InputPathType],
    method: str | None = None,
    editor: bool = False,
    downloader: bool = False,
    examinexmat: bool = False,
    browser: bool = False,
    readme: bool = False,
    afniweb: bool = False,
    global_help: bool = False,
    gopts_help: bool = False,
    help_: bool = False,
    mini_help: bool = False,
    extreme_help: bool = False,
    h_view: bool = False,
    h_web: bool = False,
    runner: Runner | None = None,
) -> AfniOpenOutputs:
    """
    A program to open various AFNI/SUMA files.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        files: Input file(s) to be opened.
        method: Method to open files (editor, downloader, browser, afni, suma,\
            1dplot, ExamineXmat, iviewer, afniweb, readme).
        editor: Same as -w editor.
        downloader: Same as -w downloader.
        examinexmat: Same as -w ExamineXmat.
        browser: Same as -w browser.
        readme: Same as -w readme.
        afniweb: Same as -w afniweb.
        global_help: Show help for global options.
        gopts_help: Show help for global options.
        help_: The entire help output.
        mini_help: Mini help.
        extreme_help: Extreme help.
        h_view: Open help in text editor.
        h_web: Open help in web browser.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `AfniOpenOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(AFNI_OPEN_METADATA)
    cargs = []
    cargs.append("afni_open")
    cargs.extend([execution.input_file(f) for f in files])
    if method is not None:
        cargs.extend([
            "-w",
            method
        ])
    if editor:
        cargs.append("-e")
    if downloader:
        cargs.append("-d")
    if examinexmat:
        cargs.append("-x")
    if browser:
        cargs.append("-b")
    if readme:
        cargs.append("-r")
    if afniweb:
        cargs.append("-aw")
    if global_help:
        cargs.append("-global_help")
    if gopts_help:
        cargs.append("-gopts_help")
    if help_:
        cargs.append("-help")
    if mini_help:
        cargs.append("-h")
    if extreme_help:
        cargs.append("-HELP")
    if h_view:
        cargs.append("-h_view")
    if h_web:
        cargs.append("-h_web")
    ret = AfniOpenOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "AFNI_OPEN_METADATA",
    "AfniOpenOutputs",
    "afni_open",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_MAKE_AVERAGE_SURFACE_METADATA = Metadata(
    id="c7c7dc6c877d2ef020d99e894c96f070fb1a71d2.boutiques",
    name="mris_make_average_surface",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisMakeAverageSurfaceOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_make_average_surface(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_surface: OutputPathType | None
    """Output averaged surface"""


def mris_make_average_surface(
    hemi: str,
    outsurfname: str,
    cansurfname: str,
    outsubject: str,
    subjects: list[str],
    sdir: str | None = None,
    sdir_out: str | None = None,
    nonorm_flag: bool = False,
    icoorder: float | None = None,
    xfmname: str | None = None,
    templatename: str | None = None,
    surfname: str | None = None,
    surf2surf_flag: bool = False,
    simple: list[str] | None = None,
    diagno: float | None = None,
    runner: Runner | None = None,
) -> MrisMakeAverageSurfaceOutputs:
    """
    A program to average the orig surfaces from the given subject list into a single
    surface using Talairach coords and the spherical transform.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        hemi: Hemisphere, lh or rh.
        outsurfname: Output surface name (e.g., avg_orig).
        cansurfname: Registration surface (e.g., sphere.reg).
        outsubject: Name of subject to store the results in.
        subjects: List of subjects to average.
        sdir: Use sdir instead of SUBJECTS_DIR.
        sdir_out: Save results in sdirout/outsubject instead of\
            SUBJECTS_DIR/outsubject.
        nonorm_flag: Do not normalize area.
        icoorder: Use given icosahedron order (default is 7).
        xfmname: Use transforms/xfmname instead of talairach.xfm.
        templatename: Volume to use as geometry template for output surfaces.
        surfname: Use surfname instead of orig.
        surf2surf_flag: Use surf2surf transform instead of parametric surface.
        simple: Compute an average surface from the list of surfaces. All\
            surfaces must have same number of vertices.
        diagno: Set Gdiag_no to diagno.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisMakeAverageSurfaceOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_MAKE_AVERAGE_SURFACE_METADATA)
    cargs = []
    cargs.append("mris_make_average_surface")
    cargs.append(hemi)
    cargs.append(outsurfname)
    cargs.append(cansurfname)
    cargs.append(outsubject)
    cargs.extend(subjects)
    if sdir is not None:
        cargs.extend([
            "-sdir",
            sdir
        ])
    if sdir_out is not None:
        cargs.extend([
            "-sdir-out",
            sdir_out
        ])
    if nonorm_flag:
        cargs.append("-nonorm")
    if icoorder is not None:
        cargs.extend([
            "-i",
            str(icoorder)
        ])
    if xfmname is not None:
        cargs.extend([
            "-x",
            xfmname
        ])
    if templatename is not None:
        cargs.extend([
            "-t",
            templatename
        ])
    if surfname is not None:
        cargs.extend([
            "-s",
            surfname
        ])
    if surf2surf_flag:
        cargs.append("-surf2surf")
    if simple is not None:
        cargs.extend([
            "-simple",
            *simple
        ])
    if diagno is not None:
        cargs.extend([
            "-v",
            str(diagno)
        ])
    ret = MrisMakeAverageSurfaceOutputs(
        root=execution.output_file("."),
        output_surface=execution.output_file(sdir_out + "/" + outsubject + "/" + outsurfname) if (sdir_out is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_MAKE_AVERAGE_SURFACE_METADATA",
    "MrisMakeAverageSurfaceOutputs",
    "mris_make_average_surface",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_WARP_CONVERT_METADATA = Metadata(
    id="36b7f6d3b0edf16e088ad567445e656a71a7dd89.boutiques",
    name="mri_warp_convert",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriWarpConvertOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_warp_convert(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    outwarp: OutputPathType | None
    """Converted output warp file"""


def mri_warp_convert(
    invox: InputPathType | None = None,
    outvox: str | None = None,
    insrcgeom: InputPathType | None = None,
    downsample: bool = False,
    runner: Runner | None = None,
) -> MriWarpConvertOutputs:
    """
    This program converts non-linear deformation field warp file formats.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        invox: Input file with displacements in source-voxel space.
        outvox: Output file with displacements in source-voxel space.
        insrcgeom: Specify source image geometry (moving volume).
        downsample: Downsample output M3Z to spacing of 2.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriWarpConvertOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_WARP_CONVERT_METADATA)
    cargs = []
    cargs.append("mri_warp_convert")
    if invox is not None:
        cargs.extend([
            "--invox",
            execution.input_file(invox)
        ])
    if outvox is not None:
        cargs.extend([
            "--outvox",
            outvox
        ])
    if insrcgeom is not None:
        cargs.extend([
            "--insrcgeom",
            execution.input_file(insrcgeom)
        ])
    if downsample:
        cargs.append("--downsample")
    ret = MriWarpConvertOutputs(
        root=execution.output_file("."),
        outwarp=execution.output_file(outvox) if (outvox is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_WARP_CONVERT_METADATA",
    "MriWarpConvertOutputs",
    "mri_warp_convert",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

CONVERT_WARPFIELD_METADATA = Metadata(
    id="e0f48a3f4d002bf731b7f13e5d1964bc0562c643.boutiques",
    name="convert-warpfield",
    package="workbench",
    container_image_tag="brainlife/connectome_workbench:1.5.0-freesurfer-update",
)


@dataclasses.dataclass
class ConvertWarpfieldFromWorld:
    """
    input is a NIFTI 'world' warpfield.
    """
    input_: str
    """the input warpfield"""
    opt_absolute: bool = False
    """warpfield was written in absolute convention, rather than relative"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-from-world")
        cargs.append(self.input_)
        if self.opt_absolute:
            cargs.append("-absolute")
        return cargs


@dataclasses.dataclass
class ConvertWarpfieldFromFnirt:
    """
    input is a fnirt warpfield.
    """
    input_: str
    """the input warpfield"""
    source_volume: str
    """the source volume used when generating the input warpfield"""
    opt_absolute: bool = False
    """warpfield was written in absolute convention, rather than relative"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-from-fnirt")
        cargs.append(self.input_)
        cargs.append(self.source_volume)
        if self.opt_absolute:
            cargs.append("-absolute")
        return cargs


@dataclasses.dataclass
class ConvertWarpfieldToFnirt:
    """
    write output as a fnirt warpfield.
    """
    output: str
    """output - the output warpfield"""
    source_volume: str
    """the volume you want to apply the warpfield to"""
    
    def run(
        self,
        execution: Execution,
    ) -> list[str]:
        """
        Build command line arguments. This method is called by the main command.
        
        Args:
            execution: The execution object.
        Returns:
            Command line arguments
        """
        cargs = []
        cargs.append("-to-fnirt")
        cargs.append(self.output)
        cargs.append(self.source_volume)
        return cargs


class ConvertWarpfieldOutputs(typing.NamedTuple):
    """
    Output object returned when calling `convert_warpfield(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def convert_warpfield(
    from_world: ConvertWarpfieldFromWorld | None = None,
    opt_from_itk_input: str | None = None,
    from_fnirt: ConvertWarpfieldFromFnirt | None = None,
    opt_to_world_output: str | None = None,
    opt_to_itk_output: str | None = None,
    to_fnirt: list[ConvertWarpfieldToFnirt] | None = None,
    runner: Runner | None = None,
) -> ConvertWarpfieldOutputs:
    """
    Convert a warpfield between conventions.
    
    NIFTI world warpfields can be used directly on mm coordinates via sampling
    the three subvolumes at the coordinate and adding the sampled values to the
    coordinate vector. They use the NIFTI coordinate system, that is, X is left
    to right, Y is posterior to anterior, and Z is inferior to superior.
    
    NOTE: this command does not invert the warpfield, and to warp a surface, you
    must use the inverse of the warpfield that warps the corresponding volume.
    
    The ITK format is used by ANTS.
    
    You must specify exactly one -from option, but you may specify multiple -to
    options, and -to-fnirt may be specified more than once.
    
    Author: Connectome Workbench Developers
    
    URL: https://github.com/Washington-University/workbench
    
    Args:
        from_world: input is a NIFTI 'world' warpfield.
        opt_from_itk_input: input is an ITK warpfield: the input warpfield.
        from_fnirt: input is a fnirt warpfield.
        opt_to_world_output: write output as a NIFTI 'world' warpfield: output\
            - the output warpfield.
        opt_to_itk_output: write output as an ITK warpfield: output - the\
            output warpfield.
        to_fnirt: write output as a fnirt warpfield.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ConvertWarpfieldOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(CONVERT_WARPFIELD_METADATA)
    cargs = []
    cargs.append("wb_command")
    cargs.append("-convert-warpfield")
    if from_world is not None:
        cargs.extend(from_world.run(execution))
    if opt_from_itk_input is not None:
        cargs.extend([
            "-from-itk",
            opt_from_itk_input
        ])
    if from_fnirt is not None:
        cargs.extend(from_fnirt.run(execution))
    if opt_to_world_output is not None:
        cargs.extend([
            "-to-world",
            opt_to_world_output
        ])
    if opt_to_itk_output is not None:
        cargs.extend([
            "-to-itk",
            opt_to_itk_output
        ])
    if to_fnirt is not None:
        cargs.extend([a for c in [s.run(execution) for s in to_fnirt] for a in c])
    ret = ConvertWarpfieldOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "CONVERT_WARPFIELD_METADATA",
    "ConvertWarpfieldFromFnirt",
    "ConvertWarpfieldFromWorld",
    "ConvertWarpfieldOutputs",
    "ConvertWarpfieldToFnirt",
    "convert_warpfield",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MIST_FA_REG_METADATA = Metadata(
    id="45a9d3529b9890b437032ed4b1edac4f90d4e0ac.boutiques",
    name="mist_FA_reg",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class MistFaRegOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mist_fa_reg(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_file: OutputPathType
    """Output file for the registered volume"""


def mist_fa_reg(
    fa_volume: InputPathType,
    s0_volume: InputPathType,
    reference_t1_volume: InputPathType,
    output_filename: str,
    runner: Runner | None = None,
) -> MistFaRegOutputs:
    """
    Tool for registering FA volumes to a reference T1 volume.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        fa_volume: The FA volume to be registered.
        s0_volume: The S0 volume corresponding to the FA volume.
        reference_t1_volume: The reference T1 volume to register against.
        output_filename: The output filename for the registered volume.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MistFaRegOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MIST_FA_REG_METADATA)
    cargs = []
    cargs.append("mist_FA_reg")
    cargs.append(execution.input_file(fa_volume))
    cargs.append(execution.input_file(s0_volume))
    cargs.append(execution.input_file(reference_t1_volume))
    cargs.append(output_filename)
    ret = MistFaRegOutputs(
        root=execution.output_file("."),
        output_file=execution.output_file(output_filename),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MIST_FA_REG_METADATA",
    "MistFaRegOutputs",
    "mist_fa_reg",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRIS_FILL_METADATA = Metadata(
    id="c5656563cf43beb0f218120cdf33a3244a656aa3.boutiques",
    name="mris_fill",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MrisFillOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mris_fill(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    filled_volume: OutputPathType
    """The resulting filled volume output."""


def mris_fill(
    input_surface: InputPathType,
    output_volume: str,
    resolution: float | None = None,
    conform: bool = False,
    runner: Runner | None = None,
) -> MrisFillOutputs:
    """
    A tool that floodfills the interior of a surface and writes the results into a
    volume of specified resolution.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input_surface: Input surface file.
        output_volume: Output volume file.
        resolution: Set the resolution of the output volume (default = 0.250\
            mm/voxel).
        conform: Conform the volume before writing.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MrisFillOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRIS_FILL_METADATA)
    cargs = []
    cargs.append("mris_fill")
    if resolution is not None:
        cargs.extend([
            "-r",
            str(resolution)
        ])
    if conform:
        cargs.append("-c")
    cargs.append(execution.input_file(input_surface))
    cargs.append(output_volume)
    ret = MrisFillOutputs(
        root=execution.output_file("."),
        filled_volume=execution.output_file(output_volume),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRIS_FILL_METADATA",
    "MrisFillOutputs",
    "mris_fill",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_INFO_METADATA = Metadata(
    id="fea16b2c0cef821a4d6928c8ea143c9f2909ad1b.boutiques",
    name="mri_info",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriInfoOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_info(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def mri_info(
    input1: InputPathType,
    input2: InputPathType | None = None,
    conformed: bool = False,
    conformed_to_min: bool = False,
    is_1mm_iso: bool = False,
    type_: bool = False,
    tr: bool = False,
    te: bool = False,
    ti: bool = False,
    fa: bool = False,
    pedir: bool = False,
    res: bool = False,
    cres: bool = False,
    rres: bool = False,
    sres: bool = False,
    voxvol: bool = False,
    voxvolsum: bool = False,
    ncols: bool = False,
    nrows: bool = False,
    nslices: bool = False,
    dim: bool = False,
    cdc: bool = False,
    rdc: bool = False,
    sdc: bool = False,
    vox2ras: bool = False,
    ras2vox: bool = False,
    vox2ras_tkr: bool = False,
    ras2vox_tkr: bool = False,
    vox2ras_fsl: bool = False,
    tkr2scanner: bool = False,
    scanner2tkr: bool = False,
    ras_good: bool = False,
    cras: bool = False,
    center: bool = False,
    zero_cras: bool = False,
    p0: bool = False,
    det: bool = False,
    dof: bool = False,
    nframes: bool = False,
    mid_frame: bool = False,
    format_: bool = False,
    orientation: bool = False,
    slicedirection: bool = False,
    autoalign: bool = False,
    ctab: bool = False,
    cmds: bool = False,
    dump: bool = False,
    voxel_crs: list[str] | None = None,
    entropy: bool = False,
    output_file: InputPathType | None = None,
    orig_ras2vox: bool = False,
    in_type: str | None = None,
    runner: Runner | None = None,
) -> MriInfoOutputs:
    """
    Tool to extract metadata from MRI volumes.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        input1: Primary input file.
        input2: Secondary input file (optional).
        conformed: Print whether a volume is conformed.
        conformed_to_min: Print whether a volume is conformed-to-min.
        is_1mm_iso: Print whether the voxel size is 1mm isotropic.
        type_: Print the voxel type/precision.
        tr: Print TR.
        te: Print TE.
        ti: Print TI.
        fa: Print flip angle.
        pedir: Print phase encode direction.
        res: Print column, row, slice, and frame resolution.
        cres: Print column voxel size.
        rres: Print row voxel size.
        sres: Print slice voxel size.
        voxvol: Print voxel volume.
        voxvolsum: Compute sum of all voxels times the voxel volume.
        ncols: Print number of columns.
        nrows: Print number of rows.
        nslices: Print number of slices.
        dim: Print number of columns, rows, slices, and frames.
        cdc: Print column direction cosine (x_{r,a,s}).
        rdc: Print row direction cosine (y_{r,a,s}).
        sdc: Print slice direction cosine (z_{r,a,s}).
        vox2ras: Print the native/qform vox2ras matrix.
        ras2vox: Print the native/qform ras2vox matrix.
        vox2ras_tkr: Print the tkregister vox2ras matrix.
        ras2vox_tkr: Print the tkregister ras2vox matrix.
        vox2ras_fsl: Print the FSL/FLIRT vox2ras matrix.
        tkr2scanner: Print tkrRAS-to-scannerRAS matrix.
        scanner2tkr: Print scannerRAS-to-tkrRAS matrix.
        ras_good: Print the ras_good_flag.
        cras: Print the RAS near the center of the volume.
        center: Print the RAS at the actual center of the volume.
        zero_cras: Zero the center ras.
        p0: Print the RAS at voxel (0,0,0).
        det: Print the determinant of the vox2ras matrix.
        dof: Print the degrees of freedom stored in the header.
        nframes: Print the number of frames.
        mid_frame: Print the middle frame.
        format_: Print file format.
        orientation: Print orientation string (e.g., LPS, RAS, RPI).
        slicedirection: Print primary slice direction (e.g., axial).
        autoalign: Print auto align matrix (if it exists).
        ctab: Print embedded color lookup table.
        cmds: Print command-line provenance info.
        dump: Print FA, TR, TE, TI, etc.
        voxel_crs: Dump voxel value from column, row, slice (0-based, all\
            frames).
        entropy: Compute and print entropy.
        output_file: Print flagged results to file.
        orig_ras2vox: Print orig Ras2Vox matrix if present.
        in_type: Explicitly specify file type.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriInfoOutputs`).
    """
    if voxel_crs is not None and (len(voxel_crs) != 3): 
        raise ValueError(f"Length of 'voxel_crs' must be 3 but was {len(voxel_crs)}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_INFO_METADATA)
    cargs = []
    cargs.append("mri_info")
    cargs.append(execution.input_file(input1))
    if input2 is not None:
        cargs.append(execution.input_file(input2))
    if conformed:
        cargs.append("--conformed")
    if conformed_to_min:
        cargs.append("--conformed-to-min")
    if is_1mm_iso:
        cargs.append("--is-1mm-iso")
    if type_:
        cargs.append("--type")
    if tr:
        cargs.append("--tr")
    if te:
        cargs.append("--te")
    if ti:
        cargs.append("--ti")
    if fa:
        cargs.append("--fa")
    if pedir:
        cargs.append("--pedir")
    if res:
        cargs.append("--res")
    if cres:
        cargs.append("--cres")
    if rres:
        cargs.append("--rres")
    if sres:
        cargs.append("--sres")
    if voxvol:
        cargs.append("--voxvol")
    if voxvolsum:
        cargs.append("--voxvolsum")
    if ncols:
        cargs.append("--ncols")
    if nrows:
        cargs.append("--nrows")
    if nslices:
        cargs.append("--nslices")
    if dim:
        cargs.append("--dim")
    if cdc:
        cargs.append("--cdc")
    if rdc:
        cargs.append("--rdc")
    if sdc:
        cargs.append("--sdc")
    if vox2ras:
        cargs.append("--vox2ras")
    if ras2vox:
        cargs.append("--ras2vox")
    if vox2ras_tkr:
        cargs.append("--vox2ras-tkr")
    if ras2vox_tkr:
        cargs.append("--ras2vox-tkr")
    if vox2ras_fsl:
        cargs.append("--vox2ras-fsl")
    if tkr2scanner:
        cargs.append("--tkr2scanner")
    if scanner2tkr:
        cargs.append("--scanner2tkr")
    if ras_good:
        cargs.append("--ras_good")
    if cras:
        cargs.append("--cras")
    if center:
        cargs.append("--center")
    if zero_cras:
        cargs.append("--zero-cras")
    if p0:
        cargs.append("--p0")
    if det:
        cargs.append("--det")
    if dof:
        cargs.append("--dof")
    if nframes:
        cargs.append("--nframes")
    if mid_frame:
        cargs.append("--mid-frame")
    if format_:
        cargs.append("--format")
    if orientation:
        cargs.append("--orientation")
    if slicedirection:
        cargs.append("--slicedirection")
    if autoalign:
        cargs.append("--autoalign")
    if ctab:
        cargs.append("--ctab")
    if cmds:
        cargs.append("--cmds")
    if dump:
        cargs.append("--dump")
    if voxel_crs is not None:
        cargs.extend([
            "--voxel",
            *voxel_crs
        ])
    if entropy:
        cargs.append("--entropy")
    if output_file is not None:
        cargs.extend([
            "--o",
            execution.input_file(output_file)
        ])
    if orig_ras2vox:
        cargs.append("--orig_ras2vox")
    if in_type is not None:
        cargs.extend([
            "--in_type",
            in_type
        ])
    ret = MriInfoOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_INFO_METADATA",
    "MriInfoOutputs",
    "mri_info",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_DIFF_METADATA = Metadata(
    id="e29e7f056291727390ed03afe0470b3873fe4e24.boutiques",
    name="mri_diff",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriDiffOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_diff(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    log_output: OutputPathType | None
    """Log file containing difference information."""
    difference_image_output: OutputPathType | None
    """Difference image output file."""
    suspicious_difference_output: OutputPathType | None
    """Volume with suspicious differences labeled."""


def mri_diff(
    vol1file: InputPathType,
    vol2file: InputPathType,
    resolution_check: bool = False,
    acquisition_param_check: bool = False,
    geometry_check: bool = False,
    precision_check: bool = False,
    pixel_check: bool = False,
    orientation_check: bool = False,
    file_type_diff_check: bool = False,
    no_exit_on_diff: bool = False,
    quality_assurance: bool = False,
    pixel_only: bool = False,
    abs_difference: bool = False,
    no_abs_difference: bool = False,
    difference_abs: bool = False,
    percentage_difference: bool = False,
    rss_save: bool = False,
    ssd_print: bool = False,
    rms_print: bool = False,
    count_diff_voxels: bool = False,
    pixel_threshold: float | None = None,
    count_thresh_voxels: float | None = None,
    log_file: str | None = None,
    difference_image: InputPathType | None = None,
    suspicious_diff_volume: InputPathType | None = None,
    segmentation_diff: str | None = None,
    merge_edits: str | None = None,
    average_difference: str | None = None,
    debug_mode: bool = False,
    verbose_mode: bool = False,
    check_options: bool = False,
    runner: Runner | None = None,
) -> MriDiffOutputs:
    """
    Determines whether two volumes differ based on dimensions, resolutions,
    acquisition parameters, geometry, precision, and pixel data.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        vol1file: First volume to compare (e.g., vol1.mgz).
        vol2file: Second volume to compare (e.g., vol2.mgz).
        resolution_check: Do not check for resolution differences.
        acquisition_param_check: Do not check for acquisition parameter\
            differences.
        geometry_check: Do not check for geometry differences.
        precision_check: Do not check for precision differences.
        pixel_check: Do not check for pixel differences.
        orientation_check: Do not check for orientation differences.
        file_type_diff_check: Do not check for file type differences.
        no_exit_on_diff: Do not exit on difference; run through everything.
        quality_assurance: Check resolution, acquisition, precision, and\
            orientation only.
        pixel_only: Only check pixel data.
        abs_difference: Take absolute value of difference (default).
        no_abs_difference: Do not take absolute value of difference.
        difference_abs: Take absolute value before computing difference.
        percentage_difference: Compute percentage difference:\
            100*(v1-v2)/((v1+v2)/2).
        rss_save: Save square root sum squares with --diff.
        ssd_print: Print sum squared differences over all voxels.
        rms_print: Print root mean squared difference over all non-zero voxels.
        count_diff_voxels: Print number of differing voxels.
        pixel_threshold: Pixel differences must be greater than this value to\
            be considered different.
        count_thresh_voxels: There must be at least this many voxels that are\
            different.
        log_file: Store difference information in this log file.
        difference_image: Save difference image to specified volume.
        suspicious_diff_volume: Differing voxels replaced with label SUSPICIOUS\
            in the specified volume.
        segmentation_diff: Perform diff on voxels with specific label index.
        merge_edits: Merge edits from newauto, oldauto, and manedit volumes\
            into merged volume.
        average_difference: Save average difference to specified file.
        debug_mode: Enable debugging mode.
        verbose_mode: Print information on all differences found.
        check_options: Check options and exit without running anything.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriDiffOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_DIFF_METADATA)
    cargs = []
    cargs.append("mri_diff")
    cargs.append(execution.input_file(vol1file))
    cargs.append(execution.input_file(vol2file))
    if resolution_check:
        cargs.append("--notallow-res")
    if acquisition_param_check:
        cargs.append("--notallow-acq")
    if geometry_check:
        cargs.append("--notallow-geo")
    if precision_check:
        cargs.append("--notallow-prec")
    if pixel_check:
        cargs.append("--notallow-pix")
    if orientation_check:
        cargs.append("--notallow-ori")
    if file_type_diff_check:
        cargs.append("--notallow-type")
    if no_exit_on_diff:
        cargs.append("--no-exit-on-diff")
    if quality_assurance:
        cargs.append("--qa")
    if pixel_only:
        cargs.append("--pix-only")
    if abs_difference:
        cargs.append("--absdiff")
    if no_abs_difference:
        cargs.append("--no-absdiff")
    if difference_abs:
        cargs.append("--diffabs")
    if percentage_difference:
        cargs.append("--diffpct")
    if rss_save:
        cargs.append("--rss")
    if ssd_print:
        cargs.append("--ssd")
    if rms_print:
        cargs.append("--rms")
    if count_diff_voxels:
        cargs.append("--count")
    if pixel_threshold is not None:
        cargs.extend([
            "--thresh",
            str(pixel_threshold)
        ])
    if count_thresh_voxels is not None:
        cargs.extend([
            "--count-thresh",
            str(count_thresh_voxels)
        ])
    if log_file is not None:
        cargs.extend([
            "--log",
            log_file
        ])
    if difference_image is not None:
        cargs.extend([
            "--diff",
            execution.input_file(difference_image)
        ])
    if suspicious_diff_volume is not None:
        cargs.extend([
            "--diff_label_suspicious",
            execution.input_file(suspicious_diff_volume)
        ])
    if segmentation_diff is not None:
        cargs.extend([
            "--segdiff",
            segmentation_diff
        ])
    if merge_edits is not None:
        cargs.extend([
            "--merge-edits",
            merge_edits
        ])
    if average_difference is not None:
        cargs.extend([
            "--avg-diff",
            average_difference
        ])
    if debug_mode:
        cargs.append("--debug")
    if verbose_mode:
        cargs.append("--verbose")
    if check_options:
        cargs.append("--checkopts")
    ret = MriDiffOutputs(
        root=execution.output_file("."),
        log_output=execution.output_file(log_file) if (log_file is not None) else None,
        difference_image_output=execution.output_file(pathlib.Path(difference_image).name) if (difference_image is not None) else None,
        suspicious_difference_output=execution.output_file(pathlib.Path(suspicious_diff_volume).name) if (suspicious_diff_volume is not None) else None,
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_DIFF_METADATA",
    "MriDiffOutputs",
    "mri_diff",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

MRI_COMPUTE_LAYER_FRACTIONS_METADATA = Metadata(
    id="4b975414209d034dddfda14c61a9efcc219f17d0.boutiques",
    name="mri_compute_layer_fractions",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class MriComputeLayerFractionsOutputs(typing.NamedTuple):
    """
    Output object returned when calling `mri_compute_layer_fractions(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    layer_fractions_output: OutputPathType
    """Output file for layer fractions computation"""
    synth_output: OutputPathType
    """Synthesized output volume combining layers and aseg"""


def mri_compute_layer_fractions(
    reg_file: InputPathType,
    input_volume: InputPathType,
    output_stem: str,
    output_directory: str | None = None,
    aseg_file: InputPathType | None = None,
    target_volume: InputPathType | None = None,
    hemi_flag: bool = False,
    fs_names_flag: bool = False,
    subject_id: str | None = None,
    n_layers: float | None = None,
    synth_flag: bool = False,
    thickness: float | None = None,
    random_file: InputPathType | None = None,
    identity_file: str | None = None,
    runner: Runner | None = None,
) -> MriComputeLayerFractionsOutputs:
    """
    This program computes volumetric partial volume fractions from laminar surfaces
    using FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        reg_file: Input registration file.
        input_volume: Input volume file.
        output_stem: Output stem for generated files.
        output_directory: Output directory specified by SUBJECTS_DIR.
        aseg_file: Input ASEG file for synthesis.
        target_volume: Target volume for analysis.
        hemi_flag: Specify hemisphere processing.
        fs_names_flag: Flag to use FreeSurfer names.
        subject_id: Subject ID for processing.
        n_layers: Number of layers for volume fraction computation.
        synth_flag: Flag to combine with the ASEG for a single segmentation\
            volume.
        thickness: Specify cortical thickness fraction.
        random_file: Specify random volume file.
        identity_file: Specify identity file.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `MriComputeLayerFractionsOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(MRI_COMPUTE_LAYER_FRACTIONS_METADATA)
    cargs = []
    cargs.append("mri_compute_layer_fractions")
    cargs.append(execution.input_file(reg_file))
    cargs.append(execution.input_file(input_volume))
    cargs.append(output_stem)
    if output_directory is not None:
        cargs.extend([
            "-SDIR",
            output_directory
        ])
    if aseg_file is not None:
        cargs.extend([
            "-a",
            execution.input_file(aseg_file)
        ])
    if target_volume is not None:
        cargs.append(execution.input_file(target_volume))
    if hemi_flag:
        cargs.append("-hemi")
    if fs_names_flag:
        cargs.append("-FS_names")
    if subject_id is not None:
        cargs.extend([
            "-s",
            subject_id
        ])
    if n_layers is not None:
        cargs.extend([
            "-nlayers",
            str(n_layers)
        ])
    if synth_flag:
        cargs.append("-synth")
    if thickness is not None:
        cargs.extend([
            "-r",
            str(thickness)
        ])
    if random_file is not None:
        cargs.extend([
            "-n",
            execution.input_file(random_file)
        ])
    if identity_file is not None:
        cargs.append(identity_file)
    ret = MriComputeLayerFractionsOutputs(
        root=execution.output_file("."),
        layer_fractions_output=execution.output_file(output_stem + "_layer_fractions.mgz"),
        synth_output=execution.output_file(output_stem + "_synth.mgz"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "MRI_COMPUTE_LAYER_FRACTIONS_METADATA",
    "MriComputeLayerFractionsOutputs",
    "mri_compute_layer_fractions",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

RECON_ALL_METADATA = Metadata(
    id="de72948bacd270ce7d872b3cb30e555b07de540c.boutiques",
    name="recon-all",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class ReconAllOutputs(typing.NamedTuple):
    """
    Output object returned when calling `recon_all(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    logfile: OutputPathType
    """Log file of the recon-all process"""
    statusfile: OutputPathType
    """Status file of the recon-all process"""


def recon_all(
    subjid: str,
    autorecon3_flag: bool = False,
    hemi: str | None = None,
    pons_crs: list[float] | None = None,
    cc_crs: list[float] | None = None,
    lh_crs: list[float] | None = None,
    rh_crs: list[float] | None = None,
    nofill: bool = False,
    watershed: str | None = None,
    external_brain_mask: InputPathType | None = None,
    wsless: bool = False,
    wsmore: bool = False,
    wsatlas: bool = False,
    no_wsatlas: bool = False,
    no_wsgcaatlas: bool = False,
    wsthresh: float | None = None,
    wsseed: list[float] | None = None,
    norm_3d_iters: float | None = None,
    norm_max_grad: float | None = None,
    norm1_b: float | None = None,
    norm2_b: float | None = None,
    norm1_n: float | None = None,
    norm2_n: float | None = None,
    cm: bool = False,
    no_fix_with_ga: bool = False,
    fix_diag_only: bool = False,
    seg_wlo: float | None = None,
    seg_ghi: float | None = None,
    nothicken: bool = False,
    no_ca_align_after: bool = False,
    no_ca_align: bool = False,
    deface: bool = False,
    expert_file: InputPathType | None = None,
    xopts_use: bool = False,
    xopts_clean: bool = False,
    xopts_overwrite: bool = False,
    termscript_file: InputPathType | None = None,
    mprage: bool = False,
    washu_mprage: bool = False,
    schwartzya3t_atlas: bool = False,
    threads: float | None = None,
    waitfor_file: InputPathType | None = None,
    notify_file: InputPathType | None = None,
    log_file: InputPathType | None = None,
    status_file: InputPathType | None = None,
    noappend: bool = False,
    no_isrunning: bool = False,
    hippocampal_subfields_t1: bool = False,
    hippocampal_subfields_t2: str | None = None,
    hippocampal_subfields_t1t2: str | None = None,
    brainstem_structures: bool = False,
    subjects_dir: str | None = None,
    mail_user: str | None = None,
    umask: str | None = None,
    group_id: str | None = None,
    only_versions: bool = False,
    debug: bool = False,
    allow_coredump: bool = False,
    dontrun: bool = False,
    version: bool = False,
    help_: bool = False,
    runner: Runner | None = None,
) -> ReconAllOutputs:
    """
    Performs all, or any part of, the FreeSurfer cortical reconstruction process.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        subjid: Subject ID for the FreeSurfer analysis.
        autorecon3_flag: Process stages 24-34.
        hemi: Specify hemisphere ('lh' or 'rh').
        pons_crs: Specify CRS for pons during fill operation.
        cc_crs: Specify CRS for corpus callosum during fill operation.
        lh_crs: Specify CRS for left hemisphere during fill operation.
        rh_crs: Specify CRS for right hemisphere during fill operation.
        nofill: Do not use automatic subcortical seg to fill.
        watershed: Control skull stripping/watershed program.
        external_brain_mask: Custom external brain mask file.
        wsless: Decrease watershed threshold.
        wsmore: Increase watershed threshold.
        wsatlas: Use atlas when skull stripping.
        no_wsatlas: Do not use atlas when skull stripping.
        no_wsgcaatlas: Do not use GCA atlas when skull stripping.
        wsthresh: Explicitly set watershed threshold.
        wsseed: Identify an index (C, R, S) point in the skull.
        norm_3d_iters: Number of 3D iterations for mri_normalize.
        norm_max_grad: Max grad for mri_normalize.
        norm1_b: First usage of mri_normalize with control point intensity N\
            below target.
        norm2_b: Second usage of mri_normalize with control point intensity N\
            below target.
        norm1_n: First usage of mri_normalize, number of iterations.
        norm2_n: Second usage of mri_normalize, number of iterations.
        cm: Conform volumes to the min voxel size.
        no_fix_with_ga: Do not use genetic algorithm when fixing topology.
        fix_diag_only: Topology fixer runs until ?h.defect_labels files are\
            created.
        seg_wlo: Set WLO value for mri_segment and mris_make_surfaces.
        seg_ghi: Set GHI value for mri_segment and mris_make_surfaces.
        nothicken: Pass '-thicken 0' to mri_segment.
        no_ca_align_after: Turn off '-align-after' with mri_ca_register.
        no_ca_align: Turn off '-align' with mri_ca_label.
        deface: Deface subject, written to orig_defaced.mgz.
        expert_file: Read-in expert options file.
        xopts_use: Use pre-existing expert options file.
        xopts_clean: Delete pre-existing expert options file.
        xopts_overwrite: Overwrite pre-existing expert options file.
        termscript_file: Run script before exiting.
        mprage: Assume scan parameters are MGH MP-RAGE protocol.
        washu_mprage: Assume scan parameters are Wash.U. MP-RAGE protocol.
        schwartzya3t_atlas: Use special young adult 3T atlas for tal reg.
        threads: Set number of threads to use.
        waitfor_file: Wait for file to appear before beginning.
        notify_file: Create this file after finishing.
        log_file: Specify log file.
        status_file: Specify status file.
        noappend: Start new log and status files instead of appending.
        no_isrunning: Do not check whether this subject is currently being\
            processed.
        hippocampal_subfields_t1: Segmentation of hippocampal subfields using\
            input T1 scan.
        hippocampal_subfields_t2: Segmentation using an additional scan and\
            input T2 scan.
        hippocampal_subfields_t1t2: Segmentation using additional scan and\
            input T1.
        brainstem_structures: Segmentation of brainstem structures.
        subjects_dir: Specify subjects directory.
        mail_user: Mail user when done.
        umask: Set unix file permission mask.
        group_id: Check that current group is alpha group.
        only_versions: Print version of each binary and exit.
        debug: Print out lots of info.
        allow_coredump: Set coredump limit to unlimited.
        dontrun: Do everything but execute each command.
        version: Print version of this script and exit.
        help_: Display help message and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `ReconAllOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(RECON_ALL_METADATA)
    cargs = []
    cargs.append("recon-all")
    cargs.extend([
        "-subjid",
        subjid
    ])
    if autorecon3_flag:
        cargs.append("-autorecon3")
    if hemi is not None:
        cargs.extend([
            "-hemi",
            hemi
        ])
    if pons_crs is not None:
        cargs.extend([
            "-pons-crs",
            *map(str, pons_crs)
        ])
    if cc_crs is not None:
        cargs.extend([
            "-cc-crs",
            *map(str, cc_crs)
        ])
    if lh_crs is not None:
        cargs.extend([
            "-lh-crs",
            *map(str, lh_crs)
        ])
    if rh_crs is not None:
        cargs.extend([
            "-rh-crs",
            *map(str, rh_crs)
        ])
    if nofill:
        cargs.append("-nofill")
    if watershed is not None:
        cargs.extend([
            "-watershed",
            watershed
        ])
    if external_brain_mask is not None:
        cargs.extend([
            "-xmask",
            execution.input_file(external_brain_mask)
        ])
    if wsless:
        cargs.append("-wsless")
    if wsmore:
        cargs.append("-wsmore")
    if wsatlas:
        cargs.append("-wsatlas")
    if no_wsatlas:
        cargs.append("-no-wsatlas")
    if no_wsgcaatlas:
        cargs.append("-no-wsgcaatlas")
    if wsthresh is not None:
        cargs.extend([
            "-wsthresh",
            str(wsthresh)
        ])
    if wsseed is not None:
        cargs.extend([
            "-wsseed",
            *map(str, wsseed)
        ])
    if norm_3d_iters is not None:
        cargs.extend([
            "-norm3diters",
            str(norm_3d_iters)
        ])
    if norm_max_grad is not None:
        cargs.extend([
            "-normmaxgrad",
            str(norm_max_grad)
        ])
    if norm1_b is not None:
        cargs.extend([
            "-norm1-b",
            str(norm1_b)
        ])
    if norm2_b is not None:
        cargs.extend([
            "-norm2-b",
            str(norm2_b)
        ])
    if norm1_n is not None:
        cargs.extend([
            "-norm1-n",
            str(norm1_n)
        ])
    if norm2_n is not None:
        cargs.extend([
            "-norm2-n",
            str(norm2_n)
        ])
    if cm:
        cargs.append("-cm")
    if no_fix_with_ga:
        cargs.append("-no-fix-with-ga")
    if fix_diag_only:
        cargs.append("-fix-diag-only")
    if seg_wlo is not None:
        cargs.extend([
            "-seg-wlo",
            str(seg_wlo)
        ])
    if seg_ghi is not None:
        cargs.extend([
            "-seg-ghi",
            str(seg_ghi)
        ])
    if nothicken:
        cargs.append("-nothicken")
    if no_ca_align_after:
        cargs.append("-no-ca-align-after")
    if no_ca_align:
        cargs.append("-no-ca-align")
    if deface:
        cargs.append("-deface")
    if expert_file is not None:
        cargs.extend([
            "-expert",
            execution.input_file(expert_file)
        ])
    if xopts_use:
        cargs.append("-xopts-use")
    if xopts_clean:
        cargs.append("-xopts-clean")
    if xopts_overwrite:
        cargs.append("-xopts-overwrite")
    if termscript_file is not None:
        cargs.extend([
            "-termscript",
            execution.input_file(termscript_file)
        ])
    if mprage:
        cargs.append("-mprage")
    if washu_mprage:
        cargs.append("-washu_mprage")
    if schwartzya3t_atlas:
        cargs.append("-schwartzya3t-atlas")
    if threads is not None:
        cargs.extend([
            "-threads",
            str(threads)
        ])
    if waitfor_file is not None:
        cargs.extend([
            "-waitfor",
            execution.input_file(waitfor_file)
        ])
    if notify_file is not None:
        cargs.extend([
            "-notify",
            execution.input_file(notify_file)
        ])
    if log_file is not None:
        cargs.extend([
            "-log",
            execution.input_file(log_file)
        ])
    if status_file is not None:
        cargs.extend([
            "-status",
            execution.input_file(status_file)
        ])
    if noappend:
        cargs.append("-noappend")
    if no_isrunning:
        cargs.append("-no-isrunning")
    if hippocampal_subfields_t1:
        cargs.append("-hippocampal-subfields-T1")
    if hippocampal_subfields_t2 is not None:
        cargs.extend([
            "-hippocampal-subfields-T2",
            hippocampal_subfields_t2
        ])
    if hippocampal_subfields_t1t2 is not None:
        cargs.extend([
            "-hippocampal-subfields-T1T2",
            hippocampal_subfields_t1t2
        ])
    if brainstem_structures:
        cargs.append("-brainstem-structures")
    if subjects_dir is not None:
        cargs.extend([
            "-sd",
            subjects_dir
        ])
    if mail_user is not None:
        cargs.extend([
            "-mail",
            mail_user
        ])
    if umask is not None:
        cargs.extend([
            "-umask",
            umask
        ])
    if group_id is not None:
        cargs.extend([
            "-grp",
            group_id
        ])
    if only_versions:
        cargs.append("-onlyversions")
    if debug:
        cargs.append("-debug")
    if allow_coredump:
        cargs.append("-allowcoredump")
    if dontrun:
        cargs.append("-dontrun")
    if version:
        cargs.append("-version")
    if help_:
        cargs.append("-help")
    ret = ReconAllOutputs(
        root=execution.output_file("."),
        logfile=execution.output_file(subjid + "/scripts/recon-all.log"),
        statusfile=execution.output_file(subjid + "/scripts/recon-all-status.log"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "RECON_ALL_METADATA",
    "ReconAllOutputs",
    "recon_all",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

DMRI_TRAIN_METADATA = Metadata(
    id="918d6285f42340a49fa09c21128213fd2bfe5e71.boutiques",
    name="dmri_train",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class DmriTrainOutputs(typing.NamedTuple):
    """
    Output object returned when calling `dmri_train(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def dmri_train(
    slist: InputPathType,
    trk_files: list[InputPathType],
    seg: InputPathType,
    cmask: InputPathType,
    lmask: list[float],
    bmask_training: list[InputPathType],
    outtrk: list[InputPathType],
    bmask_test: list[InputPathType],
    ncpts: list[float],
    max_streamlines: float,
    out_files: list[str],
    rois: list[InputPathType] | None = None,
    fa: list[InputPathType] | None = None,
    reg: InputPathType | None = None,
    regnl: InputPathType | None = None,
    refnl: InputPathType | None = None,
    basereg: list[InputPathType] | None = None,
    baseref: list[InputPathType] | None = None,
    xstr: bool = False,
    aprior: bool = False,
    sprior: bool = False,
    trunc: bool = False,
    outdir: str | None = None,
    cptdir: str | None = None,
    debug: bool = False,
    checkopts: bool = False,
    help_: bool = False,
    version: bool = False,
    runner: Runner | None = None,
) -> DmriTrainOutputs:
    """
    DMRI training tool for processing diffusion MRI data in FreeSurfer.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        slist: Text file with list of training subject directories.
        trk_files: Name(s) of input .trk file(s), one per path.
        seg: Name of input aparc+aseg volume.
        cmask: Name of input cortex mask volume.
        lmask: Add a label ID from aparc+aseg to cortex mask, one per path.
        bmask_training: Input brain mask volume(s).
        outtrk: Name(s) of output, pre-sorted .trk file(s), one per path.
        bmask_test: Input brain mask volume(s) for test subject.
        ncpts: Number of control points for initial spline.
        max_streamlines: Maximum number of training streamlines to keep per\
            path.
        out_files: Base name(s) of output(s) for test subject, one per path.
        rois: Optional, names of input tract labeling ROIs, two per path.
        fa: Input FA volume(s) for test subject.
        reg: Affine registration from atlas to base space.
        regnl: Nonlinear registration from atlas to base space.
        refnl: Nonlinear registration source reference volume.
        basereg: Affine registration(s) from base to FA volume(s).
        baseref: Base space reference volume.
        xstr: Exclude previously chosen center streamline(s).
        aprior: Compute priors on underlying anatomy.
        sprior: Compute priors on shape.
        trunc: Use all training streamlines, truncated or not.
        outdir: Output directory.
        cptdir: Output directory for control points in test subject's space.
        debug: Turn on debugging.
        checkopts: Don't run anything, just check options and exit.
        help_: Print out information on how to use this program.
        version: Print out version and exit.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `DmriTrainOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(DMRI_TRAIN_METADATA)
    cargs = []
    cargs.append("dmri_train")
    cargs.extend([
        "--slist",
        execution.input_file(slist)
    ])
    cargs.extend([
        "--trk",
        *[execution.input_file(f) for f in trk_files]
    ])
    if rois is not None:
        cargs.extend([
            "--rois",
            *[execution.input_file(f) for f in rois]
        ])
    cargs.extend([
        "--seg",
        execution.input_file(seg)
    ])
    cargs.extend([
        "--cmask",
        execution.input_file(cmask)
    ])
    cargs.extend([
        "--lmask",
        *map(str, lmask)
    ])
    cargs.extend([
        "--bmask",
        *[execution.input_file(f) for f in bmask_training]
    ])
    cargs.extend([
        "--outtrk",
        *[execution.input_file(f) for f in outtrk]
    ])
    cargs.extend([
        "--bmask",
        *[execution.input_file(f) for f in bmask_test]
    ])
    if fa is not None:
        cargs.extend([
            "--fa",
            *[execution.input_file(f) for f in fa]
        ])
    if reg is not None:
        cargs.extend([
            "--reg",
            execution.input_file(reg)
        ])
    if regnl is not None:
        cargs.extend([
            "--regnl",
            execution.input_file(regnl)
        ])
    if refnl is not None:
        cargs.extend([
            "--refnl",
            execution.input_file(refnl)
        ])
    if basereg is not None:
        cargs.extend([
            "--basereg",
            *[execution.input_file(f) for f in basereg]
        ])
    if baseref is not None:
        cargs.extend([
            "--baseref",
            *[execution.input_file(f) for f in baseref]
        ])
    cargs.extend([
        "--ncpts",
        *map(str, ncpts)
    ])
    cargs.extend([
        "--max",
        str(max_streamlines)
    ])
    if xstr:
        cargs.append("--xstr")
    if aprior:
        cargs.append("--aprior")
    if sprior:
        cargs.append("--sprior")
    if trunc:
        cargs.append("--trunc")
    cargs.extend([
        "--out",
        *out_files
    ])
    if outdir is not None:
        cargs.extend([
            "--outdir",
            outdir
        ])
    if cptdir is not None:
        cargs.extend([
            "--cptdir",
            cptdir
        ])
    if debug:
        cargs.append("--debug")
    if checkopts:
        cargs.append("--checkopts")
    if help_:
        cargs.append("--help")
    if version:
        cargs.append("--version")
    ret = DmriTrainOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "DMRI_TRAIN_METADATA",
    "DmriTrainOutputs",
    "dmri_train",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

REGISTER_ELDERLY_SUBJECT_METADATA = Metadata(
    id="537220baa60ce5febcf14be16d4b791c3cbbebb9.boutiques",
    name="register_elderly_subject",
    package="freesurfer",
    container_image_tag="freesurfer/freesurfer:7.4.1",
)


class RegisterElderlySubjectOutputs(typing.NamedTuple):
    """
    Output object returned when calling `register_elderly_subject(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    transformed_fsamples_output: OutputPathType
    """Transformed control points output"""
    normalized_volume_output: OutputPathType
    """Intensity normalized volume"""


def register_elderly_subject(
    output_fsamples: str,
    output_norm: str,
    input_volume: InputPathType,
    gca_file: InputPathType,
    transform_file: InputPathType,
    sampling_percentage: float | None = 0.5,
    runner: Runner | None = None,
) -> RegisterElderlySubjectOutputs:
    """
    Tool for registering MRI images of elderly subjects using Freesurfer's
    mri_em_register.
    
    Author: FreeSurfer Developers
    
    URL: https://github.com/freesurfer/freesurfer
    
    Args:
        output_fsamples: Output path for transformed control points.
        output_norm: Output path for intensity normalized volume.
        input_volume: Input MRI volume to register.
        gca_file: GCA file for registration.
        transform_file: Output transform file.
        sampling_percentage: Percentage of white matter points to use as\
            control points.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `RegisterElderlySubjectOutputs`).
    """
    if sampling_percentage is not None and not (0 <= sampling_percentage <= 1): 
        raise ValueError(f"'sampling_percentage' must be between 0 <= x <= 1 but was {sampling_percentage}")
    runner = runner or get_global_runner()
    execution = runner.start_execution(REGISTER_ELDERLY_SUBJECT_METADATA)
    cargs = []
    cargs.append("mri_em_register")
    if sampling_percentage is not None:
        cargs.extend([
            "-p",
            str(sampling_percentage)
        ])
    cargs.extend([
        "-fsamples",
        output_fsamples
    ])
    cargs.extend([
        "-norm",
        output_norm
    ])
    cargs.append(execution.input_file(input_volume))
    cargs.append(execution.input_file(gca_file))
    cargs.append(execution.input_file(transform_file))
    ret = RegisterElderlySubjectOutputs(
        root=execution.output_file("."),
        transformed_fsamples_output=execution.output_file(output_fsamples),
        normalized_volume_output=execution.output_file(output_norm),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "REGISTER_ELDERLY_SUBJECT_METADATA",
    "RegisterElderlySubjectOutputs",
    "register_elderly_subject",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

FSLCPGEOM_METADATA = Metadata(
    id="abfea41c33a7487bc5c6fba058aaad8f45e8d06a.boutiques",
    name="fslcpgeom",
    package="fsl",
    container_image_tag="brainlife/fsl:6.0.4-patched2",
)


class FslcpgeomOutputs(typing.NamedTuple):
    """
    Output object returned when calling `fslcpgeom(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""


def fslcpgeom(
    source_file: InputPathType,
    destination_file: InputPathType,
    dimensions_flag: bool = False,
    runner: Runner | None = None,
) -> FslcpgeomOutputs:
    """
    FSL tool to copy image geometry from one file to another.
    
    Author: FMRIB Analysis Group, University of Oxford
    
    URL: https://fsl.fmrib.ox.ac.uk/fsl/fslwiki
    
    Args:
        source_file: Source image file (e.g. img1.nii.gz).
        destination_file: Destination image file (e.g. img2.nii.gz).
        dimensions_flag: Don't copy image dimensions.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `FslcpgeomOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(FSLCPGEOM_METADATA)
    cargs = []
    cargs.append("fslcpgeom")
    cargs.append(execution.input_file(source_file))
    cargs.append(execution.input_file(destination_file))
    if dimensions_flag:
        cargs.append("-d")
    ret = FslcpgeomOutputs(
        root=execution.output_file("."),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "FSLCPGEOM_METADATA",
    "FslcpgeomOutputs",
    "fslcpgeom",
]



# This file was auto generated by Styx.
# Do not edit this file directly.

import typing
import pathlib
from styxdefs import *
import dataclasses

V__TO_MNI_AWARP_METADATA = Metadata(
    id="93b77f09cd479bf6a950c0693a066eccc0f62501.boutiques",
    name="@toMNI_Awarp",
    package="afni",
    container_image_tag="afni/afni_make_build:AFNI_24.2.06",
)


class VToMniAwarpOutputs(typing.NamedTuple):
    """
    Output object returned when calling `v__to_mni_awarp(...)`.
    """
    root: OutputPathType
    """Output root folder. This is the root folder for all outputs."""
    output_datasets: OutputPathType
    """The transformed datasets in 1x1x1 mm MNI space."""


def v__to_mni_awarp(
    directory: str,
    datasets: list[InputPathType],
    runner: Runner | None = None,
) -> VToMniAwarpOutputs:
    """
    Transforms skull-stripped datasets to 1x1x1 mm MNI space using an affine
    transformation.
    
    Author: AFNI Developers
    
    URL: https://afni.nimh.nih.gov/
    
    Args:
        directory: Name of the directory to be created where results will be\
            stored.
        datasets: List of datasets to be transformed.
        runner: Command runner.
    Returns:
        NamedTuple of outputs (described in `VToMniAwarpOutputs`).
    """
    runner = runner or get_global_runner()
    execution = runner.start_execution(V__TO_MNI_AWARP_METADATA)
    cargs = []
    cargs.append("@toMNI_Awarp")
    cargs.append(directory)
    cargs.extend([execution.input_file(f) for f in datasets])
    ret = VToMniAwarpOutputs(
        root=execution.output_file("."),
        output_datasets=execution.output_file(directory + "/*"),
    )
    execution.run(cargs)
    return ret


__all__ = [
    "VToMniAwarpOutputs",
    "V__TO_MNI_AWARP_METADATA",
    "v__to_mni_awarp",
]
